summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/cgame/cg_buildable.c2
-rw-r--r--src/cgame/cg_draw.c42
-rw-r--r--src/cgame/cg_drawtools.c2
-rw-r--r--src/cgame/cg_ents.c22
-rw-r--r--src/cgame/cg_event.c8
-rw-r--r--src/cgame/cg_local.h34
-rw-r--r--src/cgame/cg_main.c22
-rw-r--r--src/cgame/cg_players.c2
-rw-r--r--src/cgame/cg_scanner.c8
-rw-r--r--src/cgame/cg_view.c2
-rw-r--r--src/game/bg_misc.c84
-rw-r--r--src/game/bg_public.h42
-rw-r--r--src/game/g_active.c8
-rw-r--r--src/game/g_buildable.c194
-rw-r--r--src/game/g_client.c86
-rw-r--r--src/game/g_cmds.c40
-rw-r--r--src/game/g_combat.c10
-rw-r--r--src/game/g_local.h10
-rw-r--r--src/game/g_main.c72
-rw-r--r--src/game/g_spawn.c8
-rw-r--r--src/game/g_target.c6
-rw-r--r--src/game/g_team.c56
-rw-r--r--src/game/g_trigger.c2
-rw-r--r--src/game/g_weapon.c6
-rw-r--r--src/ui/ui_main.c14
25 files changed, 391 insertions, 391 deletions
diff --git a/src/cgame/cg_buildable.c b/src/cgame/cg_buildable.c
index e56e62ec..b61735a7 100644
--- a/src/cgame/cg_buildable.c
+++ b/src/cgame/cg_buildable.c
@@ -394,7 +394,7 @@ void CG_Buildable( centity_t *cent )
CG_Error( "Bad item index %i on entity", es->modelindex );
//add creep
- if( es->modelindex2 == BIT_DROIDS )
+ if( es->modelindex2 == BIT_ALIENS )
CG_Creep( cent );
// if set to invisible, skip
diff --git a/src/cgame/cg_draw.c b/src/cgame/cg_draw.c
index 9fbf232b..7aee0784 100644
--- a/src/cgame/cg_draw.c
+++ b/src/cgame/cg_draw.c
@@ -305,7 +305,7 @@ void CG_DrawTeamBackground( int x, int y, int w, int h, float alpha, int team )
hcolor[0] = 1.0f;
hcolor[1] = 0.0f;
hcolor[2] = 0.0f;
- } else if ( team == TEAM_DROIDS ) {
+ } else if ( team == TEAM_ALIENS ) {
hcolor[0] = 0.0f;
hcolor[1] = 0.0f;
hcolor[2] = 1.0f;
@@ -345,23 +345,23 @@ static void CG_DrawLighting( void )
{
default:
/* if( lum < 10 )
- CG_DrawPic( -4, -4, 648, 488, cgs.media.droidNav9 );
+ CG_DrawPic( -4, -4, 648, 488, cgs.media.alienNav9 );
else if( lum >= 10 && lum < 16 )
- CG_DrawPic( -4, -4, 648, 488, cgs.media.droidNav8 );
+ CG_DrawPic( -4, -4, 648, 488, cgs.media.alienNav8 );
else if( lum >= 16 && lum < 22 )
- CG_DrawPic( -4, -4, 648, 488, cgs.media.droidNav7 );
+ CG_DrawPic( -4, -4, 648, 488, cgs.media.alienNav7 );
else if( lum >= 22 && lum < 28 )
- CG_DrawPic( -4, -4, 648, 488, cgs.media.droidNav6 );
+ CG_DrawPic( -4, -4, 648, 488, cgs.media.alienNav6 );
else if( lum >= 28 && lum < 34 )
- CG_DrawPic( -4, -4, 648, 488, cgs.media.droidNav5 );
+ CG_DrawPic( -4, -4, 648, 488, cgs.media.alienNav5 );
else if( lum >= 34 && lum < 40 )
- CG_DrawPic( -4, -4, 648, 488, cgs.media.droidNav4 );
+ CG_DrawPic( -4, -4, 648, 488, cgs.media.alienNav4 );
else if( lum >= 40 && lum < 46 )
- CG_DrawPic( -4, -4, 648, 488, cgs.media.droidNav3 );
+ CG_DrawPic( -4, -4, 648, 488, cgs.media.alienNav3 );
else if( lum >= 46 && lum < 53 )
- CG_DrawPic( -4, -4, 648, 488, cgs.media.droidNav2 );
+ CG_DrawPic( -4, -4, 648, 488, cgs.media.alienNav2 );
else if( lum >= 53 )
- CG_DrawPic( -4, -4, 648, 488, cgs.media.droidNav1 );*/
+ CG_DrawPic( -4, -4, 648, 488, cgs.media.alienNav1 );*/
break;
@@ -435,7 +435,7 @@ static void CG_DrawStatusBar( void ) {
/*if (cg.predictedPlayerState.powerups[PW_REDFLAG])
CG_DrawStatusBarFlag( 185 + CHAR_WIDTH*3 + TEXT_ICON_SPACE + ICON_SIZE, TEAM_HUMANS);
else if (cg.predictedPlayerState.powerups[PW_BLUEFLAG])
- CG_DrawStatusBarFlag( 185 + CHAR_WIDTH*3 + TEXT_ICON_SPACE + ICON_SIZE, TEAM_DROIDS);*/
+ CG_DrawStatusBarFlag( 185 + CHAR_WIDTH*3 + TEXT_ICON_SPACE + ICON_SIZE, TEAM_ALIENS);*/
/*if ( ps->stats[ STAT_ARMOR ] ) {
origin[0] = 90;
@@ -564,7 +564,7 @@ static void CG_DrawStatusBar( void ) {
#define HV_WIDTH 80
#define HV_X 555
#define HV_Y 20
- if( ps->stats[ STAT_PTEAM ] == PTE_DROIDS )
+ if( ps->stats[ STAT_PTEAM ] == PTE_ALIENS )
{
float total = cgs.dBuildPointsTotal;
float allocated = total - cgs.dBuildPoints;
@@ -582,19 +582,19 @@ static void CG_DrawStatusBar( void ) {
//
// health+armor
//
- if( ps->stats[ STAT_PTEAM ] == PTE_DROIDS )
+ if( ps->stats[ STAT_PTEAM ] == PTE_ALIENS )
{
vec4_t fcolor = { 1, 0, 0, 0.5 }; //red half alpha
vec4_t tcolor = { 0.3, 0.8, 1, 1 }; //cyan no alpha
value = (int)( (float)( (float)ps->stats[STAT_HEALTH] / ps->stats[STAT_MAX_HEALTH] ) * 100 );
- CG_DrawFadePic( 20, 0, 30, 440, fcolor, tcolor, value, cgs.media.droidHealth );
+ CG_DrawFadePic( 20, 0, 30, 440, fcolor, tcolor, value, cgs.media.alienHealth );
/* value = (int)( (float)( (float)ps->stats[STAT_ARMOR] / ps->stats[STAT_MAX_HEALTH] ) * 100 );
if( value > 0 )
- CG_DrawFadePic( 580, 0, 30, 440, fcolor, tcolor, value, cgs.media.droidHealth );*/
+ CG_DrawFadePic( 580, 0, 30, 440, fcolor, tcolor, value, cgs.media.alienHealth );*/
}
else
{
@@ -799,7 +799,7 @@ static float CG_DrawTeamOverlay( float y, qboolean right, qboolean upper ) {
}
if ( cg.snap->ps.persistant[PERS_TEAM] != TEAM_HUMANS &&
- cg.snap->ps.persistant[PERS_TEAM] != TEAM_DROIDS ) {
+ cg.snap->ps.persistant[PERS_TEAM] != TEAM_ALIENS ) {
return y; // Not on any team
}
@@ -859,7 +859,7 @@ static float CG_DrawTeamOverlay( float y, qboolean right, qboolean upper ) {
hcolor[1] = 0;
hcolor[2] = 0;
hcolor[3] = 0.33f;
- } else { // if ( cg.snap->ps.persistant[PERS_TEAM] == TEAM_DROIDS )
+ } else { // if ( cg.snap->ps.persistant[PERS_TEAM] == TEAM_ALIENS )
hcolor[0] = 0;
hcolor[1] = 0;
hcolor[2] = 1;
@@ -1014,7 +1014,7 @@ static float CG_DrawPoints( float y )
team = cg.snap->ps.stats[ STAT_PTEAM ];
- if( team == PTE_DROIDS )
+ if( team == PTE_ALIENS )
buildpoints = cgs.dBuildPoints;
else if( team == PTE_HUMANS )
buildpoints = cgs.hBuildPoints;
@@ -1081,7 +1081,7 @@ static float CG_DrawScores( float y ) {
w = CG_DrawStrlen( s ) * BIGCHAR_WIDTH + 8;
x -= w;
CG_FillRect( x, y-4, w, BIGCHAR_HEIGHT+8, color );
- if ( cg.snap->ps.persistant[PERS_TEAM] == TEAM_DROIDS ) {
+ if ( cg.snap->ps.persistant[PERS_TEAM] == TEAM_ALIENS ) {
CG_DrawPic( x, y-4, w, BIGCHAR_HEIGHT+8, cgs.media.selectShader );
}
CG_DrawBigString( x + 4, y, s, 1.0F);
@@ -1419,7 +1419,7 @@ static void CG_DrawTeamInfo( void ) {
hcolor[1] = 0.0f;
hcolor[2] = 0.0f;
hcolor[3] = 0.33f;
- } else if ( cg.snap->ps.persistant[PERS_TEAM] == TEAM_DROIDS ) {
+ } else if ( cg.snap->ps.persistant[PERS_TEAM] == TEAM_ALIENS ) {
hcolor[0] = 0.0f;
hcolor[1] = 0.0f;
hcolor[2] = 1.0f;
@@ -2031,7 +2031,7 @@ static void CG_DrawTeamVote(void) {
if ( cgs.clientinfo->team == TEAM_HUMANS )
cs_offset = 0;
- else if ( cgs.clientinfo->team == TEAM_DROIDS )
+ else if ( cgs.clientinfo->team == TEAM_ALIENS )
cs_offset = 1;
else
return;
diff --git a/src/cgame/cg_drawtools.c b/src/cgame/cg_drawtools.c
index 446018a5..d5a144e6 100644
--- a/src/cgame/cg_drawtools.c
+++ b/src/cgame/cg_drawtools.c
@@ -388,7 +388,7 @@ float *CG_TeamColor( int team ) {
switch ( team ) {
case TEAM_HUMANS:
return red;
- case TEAM_DROIDS:
+ case TEAM_ALIENS:
return blue;
case TEAM_SPECTATOR:
return spectator;
diff --git a/src/cgame/cg_ents.c b/src/cgame/cg_ents.c
index aa387211..a2f5a2b0 100644
--- a/src/cgame/cg_ents.c
+++ b/src/cgame/cg_ents.c
@@ -1054,9 +1054,9 @@ void CG_AddPacketEntities( void ) {
CG_CalcEntityLerpPositions( &cg_entities[ cg.snap->ps.clientNum ] );
//TA: "empty" item position arrays
- cgIP.numDroidItems = 0;
+ cgIP.numAlienItems = 0;
cgIP.numHumanItems = 0;
- cgIP.numDroidClients = 0;
+ cgIP.numAlienClients = 0;
cgIP.numHumanClients = 0;
for ( num = 0 ; num < cg.snap->numEntities ; num++ )
@@ -1066,11 +1066,11 @@ void CG_AddPacketEntities( void ) {
if( cent->currentState.eType == ET_BUILDABLE )
{
//TA: add to list of item positions (for creep)
- if( cent->currentState.modelindex2 == BIT_DROIDS )
+ if( cent->currentState.modelindex2 == BIT_ALIENS )
{
- VectorCopy( cent->lerpOrigin, cgIP.droidItemPositions[ cgIP.numDroidItems ] );
- cgIP.droidItemTimes[ cgIP.numDroidItems ] = cent->miscTime;
- cgIP.numDroidItems++;
+ VectorCopy( cent->lerpOrigin, cgIP.alienItemPositions[ cgIP.numAlienItems ] );
+ cgIP.alienItemTimes[ cgIP.numAlienItems ] = cent->miscTime;
+ cgIP.numAlienItems++;
}
else if( cent->currentState.modelindex2 == BIT_HUMANS )
{
@@ -1084,11 +1084,11 @@ void CG_AddPacketEntities( void ) {
int team = cent->currentState.powerups & 0x00FF;
int class = ( cent->currentState.powerups & 0xFF00 ) >> 8;
- if( team == PTE_DROIDS )
+ if( team == PTE_ALIENS )
{
- VectorCopy( cent->lerpOrigin, cgIP.droidClientPositions[ cgIP.numDroidClients ] );
- cgIP.droidClientClass = class;
- cgIP.numDroidClients++;
+ VectorCopy( cent->lerpOrigin, cgIP.alienClientPositions[ cgIP.numAlienClients ] );
+ cgIP.alienClientClass = class;
+ cgIP.numAlienClients++;
}
else if( team == PTE_HUMANS )
{
@@ -1099,7 +1099,7 @@ void CG_AddPacketEntities( void ) {
}
}
- //Com_Printf( "%d %d\n", cgIP.numDroidClients, cgIP.numHumanClients );
+ //Com_Printf( "%d %d\n", cgIP.numAlienClients, cgIP.numHumanClients );
// add each entity sent over by the server
for ( num = 0 ; num < cg.snap->numEntities ; num++ ) {
diff --git a/src/cgame/cg_local.h b/src/cgame/cg_local.h
index 44b4f9d4..8ed1a054 100644
--- a/src/cgame/cg_local.h
+++ b/src/cgame/cg_local.h
@@ -226,7 +226,7 @@ typedef enum {
LEMT_NONE,
LEMT_BURN,
LEMT_BLOOD,
- LEMT_GREENBLOOD, //TA: when droids are injured
+ LEMT_GREENBLOOD, //TA: when aliens are injured
LEMT_BANG //TA: human item explosions
} leMarkType_t; // fragment local entities can leave marks on walls
@@ -791,16 +791,16 @@ typedef struct {
qhandle_t humanTorch3;
qhandle_t humanTorch2;
qhandle_t humanTorch1;
- qhandle_t droidNav9;
- qhandle_t droidNav8;
- qhandle_t droidNav7;
- qhandle_t droidNav6;
- qhandle_t droidNav5;
- qhandle_t droidNav4;
- qhandle_t droidNav3;
- qhandle_t droidNav2;
- qhandle_t droidNav1;
- qhandle_t droidHealth;
+ qhandle_t alienNav9;
+ qhandle_t alienNav8;
+ qhandle_t alienNav7;
+ qhandle_t alienNav6;
+ qhandle_t alienNav5;
+ qhandle_t alienNav4;
+ qhandle_t alienNav3;
+ qhandle_t alienNav2;
+ qhandle_t alienNav1;
+ qhandle_t alienHealth;
qhandle_t flameShader[ 32 ];
qhandle_t flameExplShader;
@@ -1107,16 +1107,16 @@ extern markPoly_t cg_markPolys[MAX_MARK_POLYS];
//TA:
typedef struct
{
- vec3_t droidItemPositions[ MAX_ITEMS ];
- int droidItemTimes[ MAX_ITEMS ];
- int numDroidItems;
+ vec3_t alienItemPositions[ MAX_ITEMS ];
+ int alienItemTimes[ MAX_ITEMS ];
+ int numAlienItems;
vec3_t humanItemPositions[ MAX_ITEMS ];
int numHumanItems;
- vec3_t droidClientPositions[ MAX_CLIENTS ];
- int droidClientClass;
- int numDroidClients;
+ vec3_t alienClientPositions[ MAX_CLIENTS ];
+ int alienClientClass;
+ int numAlienClients;
vec3_t humanClientPositions[ MAX_CLIENTS ];
int humanClientClass;
diff --git a/src/cgame/cg_main.c b/src/cgame/cg_main.c
index 3a384845..7cc25a3f 100644
--- a/src/cgame/cg_main.c
+++ b/src/cgame/cg_main.c
@@ -752,7 +752,7 @@ static void CG_RegisterGraphics( void ) {
/*cgs.media.creepShader = trap_R_RegisterShader( "creep" );*/
- cgs.media.scannerBlipShader = trap_R_RegisterShader( "gfx/2d/droidhealth" );
+ cgs.media.scannerBlipShader = trap_R_RegisterShader( "gfx/2d/alienhealth" );
cgs.media.scannerLineShader = trap_R_RegisterShader( "gfx/2d/func/mult2" );
/*cgs.media.scannerShader = trap_R_RegisterShader( "gfx/2d/scanner" );*/
@@ -815,16 +815,16 @@ static void CG_RegisterGraphics( void ) {
cgs.media.humanTorch3 = trap_R_RegisterShader( "humanTorch3" );
cgs.media.humanTorch2 = trap_R_RegisterShader( "humanTorch2" );
cgs.media.humanTorch1 = trap_R_RegisterShader( "humanTorch1" );
- cgs.media.droidNav9 = trap_R_RegisterShader( "droidNav9" );
- cgs.media.droidNav8 = trap_R_RegisterShader( "droidNav8" );
- cgs.media.droidNav7 = trap_R_RegisterShader( "droidNav7" );
- cgs.media.droidNav6 = trap_R_RegisterShader( "droidNav6" );
- cgs.media.droidNav5 = trap_R_RegisterShader( "droidNav5" );
- cgs.media.droidNav4 = trap_R_RegisterShader( "droidNav4" );
- cgs.media.droidNav3 = trap_R_RegisterShader( "droidNav3" );
- cgs.media.droidNav2 = trap_R_RegisterShader( "droidNav2" );
- cgs.media.droidNav1 = trap_R_RegisterShader( "droidNav1" );
- cgs.media.droidHealth = trap_R_RegisterShader( "gfx/2d/droidhealth.tga" );
+ cgs.media.alienNav9 = trap_R_RegisterShader( "alienNav9" );
+ cgs.media.alienNav8 = trap_R_RegisterShader( "alienNav8" );
+ cgs.media.alienNav7 = trap_R_RegisterShader( "alienNav7" );
+ cgs.media.alienNav6 = trap_R_RegisterShader( "alienNav6" );
+ cgs.media.alienNav5 = trap_R_RegisterShader( "alienNav5" );
+ cgs.media.alienNav4 = trap_R_RegisterShader( "alienNav4" );
+ cgs.media.alienNav3 = trap_R_RegisterShader( "alienNav3" );
+ cgs.media.alienNav2 = trap_R_RegisterShader( "alienNav2" );
+ cgs.media.alienNav1 = trap_R_RegisterShader( "alienNav1" );
+ cgs.media.alienHealth = trap_R_RegisterShader( "gfx/2d/alienhealth.tga" );
cgs.media.armorModel = trap_R_RegisterModel( "models/powerups/armor/armor_yel.md3" );
cgs.media.armorIcon = trap_R_RegisterShaderNoMip( "icons/iconr_yellow" );
diff --git a/src/cgame/cg_players.c b/src/cgame/cg_players.c
index 016eebd7..9a95556c 100644
--- a/src/cgame/cg_players.c
+++ b/src/cgame/cg_players.c
@@ -1951,7 +1951,7 @@ void CG_Player( centity_t *cent )
//
CG_AddPlayerWeapon( &torso, NULL, cent );
- if( ( cg.predictedPlayerState.stats[ STAT_PTEAM ] == PTE_DROIDS ) &&
+ if( ( cg.predictedPlayerState.stats[ STAT_PTEAM ] == PTE_ALIENS ) &&
( ( cent->currentState.powerups & 0xFF ) == PTE_HUMANS ) )
trap_R_AddAdditiveLightToScene( cent->lerpOrigin, 64, 0.1, 0.1, 0.4 );
}
diff --git a/src/cgame/cg_scanner.c b/src/cgame/cg_scanner.c
index e02939bd..c4a7a067 100644
--- a/src/cgame/cg_scanner.c
+++ b/src/cgame/cg_scanner.c
@@ -77,10 +77,10 @@ void CG_Scanner( )
}
//draw alien items below scanner plane
- for( i = 0; i < cgIP.numDroidItems; i++ )
+ for( i = 0; i < cgIP.numAlienItems; i++ )
{
VectorClear( relOrigin );
- VectorSubtract( cgIP.droidItemPositions[ i ], origin, relOrigin );
+ VectorSubtract( cgIP.alienItemPositions[ i ], origin, relOrigin );
if( VectorLength( relOrigin ) < RANGE && ( relOrigin[ 2 ] < 0 ) )
CG_DrawBlips( relOrigin, aIbelow );
@@ -99,10 +99,10 @@ void CG_Scanner( )
}
//draw alien items above scanner plane
- for( i = 0; i < cgIP.numDroidItems; i++ )
+ for( i = 0; i < cgIP.numAlienItems; i++ )
{
VectorClear( relOrigin );
- VectorSubtract( cgIP.droidItemPositions[ i ], origin, relOrigin );
+ VectorSubtract( cgIP.alienItemPositions[ i ], origin, relOrigin );
if( VectorLength( relOrigin ) < RANGE && ( relOrigin[ 2 ] > 0 ) )
CG_DrawBlips( relOrigin, aIabove );
diff --git a/src/cgame/cg_view.c b/src/cgame/cg_view.c
index a8c04291..46d8d822 100644
--- a/src/cgame/cg_view.c
+++ b/src/cgame/cg_view.c
@@ -1167,7 +1167,7 @@ void CG_DrawActiveFrame( int serverTime, stereoFrame_t stereoView, qboolean demo
}
}
- if( cg.predictedPlayerState.stats[ STAT_PTEAM ] == PTE_DROIDS &&
+ if( cg.predictedPlayerState.stats[ STAT_PTEAM ] == PTE_ALIENS &&
cg.predictedPlayerState.persistant[PERS_TEAM] != TEAM_SPECTATOR )
trap_R_AddAdditiveLightToScene( cg.predictedPlayerState.origin, 500, 0.07f, 0.07f, 0.07f );
diff --git a/src/game/bg_misc.c b/src/game/bg_misc.c
index 2f8bd7a1..aacc5efb 100644
--- a/src/game/bg_misc.c
+++ b/src/game/bg_misc.c
@@ -255,7 +255,7 @@ gitem_t bg_itemlist[] =
{ "models/weapons2/gauntlet/gauntlet.md3",
0, 0, 0},
"icons/iconw_gauntlet",
- "Droid Build",
+ "Alien Build",
0,
IT_WEAPON,
WP_DBUILD,
@@ -271,7 +271,7 @@ gitem_t bg_itemlist[] =
{ "models/weapons2/gauntlet/gauntlet.md3",
0, 0, 0},
"icons/iconw_gauntlet",
- "Droid Build 2",
+ "Alien Build 2",
0,
IT_WEAPON,
WP_DBUILD2,
@@ -955,10 +955,10 @@ int bg_numItems = sizeof(bg_itemlist) / sizeof(bg_itemlist[0]) - 1;
buildableAttributes_t bg_buildableList[ ] =
{
{
- BA_D_SPAWN, //int buildNum;
+ BA_A_SPAWN, //int buildNum;
"bioegg", //char *buildName;
"Egg", //char *humanName;
- "team_droid_spawn", //char *entityName;
+ "team_alien_spawn", //char *entityName;
{ "models/buildables/bioegg/bioegg.md3", 0, 0, 0 },
{ -15, -15, -15 }, //vec3_t mins;
{ 15, 15, 15 }, //vec3_t maxs;
@@ -970,7 +970,7 @@ buildableAttributes_t bg_buildableList[ ] =
50, //int splashDamage;
200, //int splashRadius;
MOD_DSPAWN, //int meansOfDeath;
- BIT_DROIDS, //int team;
+ BIT_ALIENS, //int team;
( 1 << WP_DBUILD )|( 1 << WP_DBUILD2 ), //weapon_t buildWeapon;
BANIM_IDLE1, //int idleAnim;
100, //int nextthink;
@@ -984,10 +984,10 @@ buildableAttributes_t bg_buildableList[ ] =
qfalse //qboolean reactorTest;
},
{
- BA_D_BARRICADE, //int buildNum;
+ BA_A_BARRICADE, //int buildNum;
"barricade", //char *buildName;
"Barricade", //char *humanName;
- "team_droid_barricade",//char *entityName;
+ "team_alien_barricade",//char *entityName;
{ "models/buildables/barricade/barricade.md3", 0, 0, 0 },
{ -15, -15, -15 }, //vec3_t mins;
{ 15, 15, 15 }, //vec3_t maxs;
@@ -999,7 +999,7 @@ buildableAttributes_t bg_buildableList[ ] =
20, //int splashDamage;
50, //int splashRadius;
MOD_DSPAWN, //int meansOfDeath;
- BIT_DROIDS, //int team;
+ BIT_ALIENS, //int team;
( 1 << WP_DBUILD )|( 1 << WP_DBUILD2 ), //weapon_t buildWeapon;
BANIM_IDLE1, //int idleAnim;
100, //int nextthink;
@@ -1013,10 +1013,10 @@ buildableAttributes_t bg_buildableList[ ] =
qfalse //qboolean reactorTest;
},
{
- BA_D_BOOSTER, //int buildNum;
+ BA_A_BOOSTER, //int buildNum;
"booster", //char *buildName;
"Booster", //char *humanName;
- "team_droid_booster", //char *entityName;
+ "team_alien_booster", //char *entityName;
{ "models/buildables/booster/booster.md3", 0, 0, 0 },
{ -26, -26, -9 }, //vec3_t mins;
{ 26, 26, 9 }, //vec3_t maxs;
@@ -1028,7 +1028,7 @@ buildableAttributes_t bg_buildableList[ ] =
20, //int splashDamage;
50, //int splashRadius;
MOD_DSPAWN, //int meansOfDeath;
- BIT_DROIDS, //int team;
+ BIT_ALIENS, //int team;
( 1 << WP_DBUILD )|( 1 << WP_DBUILD2 ), //weapon_t buildWeapon;
BANIM_IDLE1, //int idleAnim;
100, //int nextthink;
@@ -1042,10 +1042,10 @@ buildableAttributes_t bg_buildableList[ ] =
qfalse //qboolean reactorTest;
},
{
- BA_D_ACIDTUBE, //int buildNum;
+ BA_A_ACIDTUBE, //int buildNum;
"acid_tube", //char *buildName;
"Acid Tube", //char *humanName;
- "team_droid_acid_tube",//char *entityName;
+ "team_alien_acid_tube",//char *entityName;
{ "models/buildables/acid_tube/acid_tube.md3", 0, 0, 0 },
{ -15, -15, -15 }, //vec3_t mins;
{ 15, 15, 15 }, //vec3_t maxs;
@@ -1057,7 +1057,7 @@ buildableAttributes_t bg_buildableList[ ] =
20, //int splashDamage;
400, //int splashRadius;
MOD_DSPAWN, //int meansOfDeath;
- BIT_DROIDS, //int team;
+ BIT_ALIENS, //int team;
( 1 << WP_DBUILD )|( 1 << WP_DBUILD2 ), //weapon_t buildWeapon;
BANIM_IDLE1, //int idleAnim;
500, //int nextthink;
@@ -1071,10 +1071,10 @@ buildableAttributes_t bg_buildableList[ ] =
qfalse //qboolean reactorTest;
},
{
- BA_D_TRAPPER, //int buildNum;
+ BA_A_TRAPPER, //int buildNum;
"trapper", //char *buildName;
"Trapper", //char *humanName;
- "team_droid_trapper", //char *entityName;
+ "team_alien_trapper", //char *entityName;
{ "models/buildables/trapper/trapper.md3", 0, 0, 0 },
{ -15, -15, -15 }, //vec3_t mins;
{ 15, 15, 15 }, //vec3_t maxs;
@@ -1086,7 +1086,7 @@ buildableAttributes_t bg_buildableList[ ] =
20, //int splashDamage;
50, //int splashRadius;
MOD_DSPAWN, //int meansOfDeath;
- BIT_DROIDS, //int team;
+ BIT_ALIENS, //int team;
( 1 << WP_DBUILD )|( 1 << WP_DBUILD2 ), //weapon_t buildWeapon;
BANIM_IDLE1, //int idleAnim;
1000, //int nextthink;
@@ -1100,10 +1100,10 @@ buildableAttributes_t bg_buildableList[ ] =
qfalse //qboolean reactorTest;
},
{
- BA_D_HIVEMIND, //int buildNum;
+ BA_A_HIVEMIND, //int buildNum;
"hivemind", //char *buildName;
"Hivemind", //char *humanName;
- "team_droid_hivemind", //char *entityName;
+ "team_alien_hivemind", //char *entityName;
{ "models/buildables/hivemind/hivemind.md3", 0, 0, 0 },
{ -15, -15, -15 }, //vec3_t mins;
{ 15, 15, 15 }, //vec3_t maxs;
@@ -1115,7 +1115,7 @@ buildableAttributes_t bg_buildableList[ ] =
20, //int splashDamage;
50, //int splashRadius;
MOD_DSPAWN, //int meansOfDeath;
- BIT_DROIDS, //int team;
+ BIT_ALIENS, //int team;
( 1 << WP_DBUILD )|( 1 << WP_DBUILD2 ), //weapon_t buildWeapon;
BANIM_IDLE1, //int idleAnim;
-1, //int nextthink;
@@ -2002,7 +2002,7 @@ int BG_FindUniqueTestForBuildable( int bclass )
classAttributes_t bg_classList[ ] =
{
{
- PCL_D_B_BASE, //int classnum;
+ PCL_A_B_BASE, //int classnum;
"Builder", //char *className;
"Builder", //char *humanName;
"lucy", //char *modelname;
@@ -2022,12 +2022,12 @@ classAttributes_t bg_classList[ ] =
350, //int steptime;
0.8f, //float speed;
1.0f, //float sticky;
- { PCL_D_B_LEV1, PCL_NONE, PCL_NONE }, //int children[ 3 ];
+ { PCL_A_B_LEV1, PCL_NONE, PCL_NONE }, //int children[ 3 ];
2000, //int timetoevolve;
100 //int value;
},
{
- PCL_D_B_LEV1, //int classnum;
+ PCL_A_B_LEV1, //int classnum;
"BuilderLevel1", //char *classname;
"Advanced Builder", //char *humanname;
"lucy", //char *modelname;
@@ -2052,7 +2052,7 @@ classAttributes_t bg_classList[ ] =
100 //int value;
},
{
- PCL_D_O_BASE, //int classnum;
+ PCL_A_O_BASE, //int classnum;
"Offensive", //char *classname;
"Offensive", //char *humanname;
"klesk", //char *modelname;
@@ -2072,12 +2072,12 @@ classAttributes_t bg_classList[ ] =
25, //int steptime;
1.8f, //float speed;
5.0f, //float sticky;
- { PCL_D_O_LEV1, PCL_NONE, PCL_NONE }, //int children[ 3 ];
+ { PCL_A_O_LEV1, PCL_NONE, PCL_NONE }, //int children[ 3 ];
3000, //int timetoevolve;
100 //int value;
},
{
- PCL_D_O_LEV1, //int classnum;
+ PCL_A_O_LEV1, //int classnum;
"OffensiveLevel1", //char *classname;
"Offensive Level 1", //char *humanname;
"anarki", //char *modelname;
@@ -2097,12 +2097,12 @@ classAttributes_t bg_classList[ ] =
25, //int steptime;
1.6f, //float speed;
4.0f, //float sticky;
- { PCL_D_O_LEV2, PCL_D_O_LEV1_UPG, PCL_NONE }, //int children[ 3 ];
+ { PCL_A_O_LEV2, PCL_A_O_LEV1_UPG, PCL_NONE }, //int children[ 3 ];
3000, //int timetoevolve;
100 //int value;
},
{
- PCL_D_O_LEV1_UPG, //int classnum;
+ PCL_A_O_LEV1_UPG, //int classnum;
"OffensiveLevel1-Upgrade", //char *classname;
"Offensive Level 1 Upgrade", //char *humanname;
"anarki", //char *modelname;
@@ -2122,12 +2122,12 @@ classAttributes_t bg_classList[ ] =
25, //int steptime;
1.6f, //float speed;
4.0f, //float sticky;
- { PCL_D_O_LEV2, PCL_NONE, PCL_NONE }, //int children[ 3 ];
+ { PCL_A_O_LEV2, PCL_NONE, PCL_NONE }, //int children[ 3 ];
3000, //int timetoevolve;
100 //int value;
},
{
- PCL_D_O_LEV2, //int classnum;
+ PCL_A_O_LEV2, //int classnum;
"OffensiveLevel2", //char *classname;
"Offensive Level 2", //char *humanname;
"bones", //char *modelname;
@@ -2147,12 +2147,12 @@ classAttributes_t bg_classList[ ] =
25, //int steptime;
1.5f, //float speed;
3.0f, //float sticky;
- { PCL_D_O_LEV3, PCL_D_O_LEV2_UPG, PCL_NONE }, //int children[ 3 ];
+ { PCL_A_O_LEV3, PCL_A_O_LEV2_UPG, PCL_NONE }, //int children[ 3 ];
3000, //int timetoevolve;
100 //int value;
},
{
- PCL_D_O_LEV2_UPG, //int classnum;
+ PCL_A_O_LEV2_UPG, //int classnum;
"OffensiveLevel2-Upgrade", //char *classname;
"Offensive Level 2 Upgrade", //char *humanname;
"bones", //char *modelname;
@@ -2172,12 +2172,12 @@ classAttributes_t bg_classList[ ] =
25, //int steptime;
1.5f, //float speed;
3.0f, //float sticky;
- { PCL_D_O_LEV3, PCL_NONE, PCL_NONE }, //int children[ 3 ];
+ { PCL_A_O_LEV3, PCL_NONE, PCL_NONE }, //int children[ 3 ];
3000, //int timetoevolve;
100 //int value;
},
{
- PCL_D_O_LEV3, //int classnum;
+ PCL_A_O_LEV3, //int classnum;
"OffensiveLevel3", //char *classname;
"Offensive Level 3", //char *humanname;
"orbb", //char *modelname;
@@ -2197,12 +2197,12 @@ classAttributes_t bg_classList[ ] =
60, //int steptime;
1.3f, //float speed;
5.0f, //float sticky;
- { PCL_D_O_LEV4, PCL_D_O_LEV3_UPG, PCL_NONE }, //int children[ 3 ];
+ { PCL_A_O_LEV4, PCL_A_O_LEV3_UPG, PCL_NONE }, //int children[ 3 ];
3000, //int timetoevolve;
100 //int value;
},
{
- PCL_D_O_LEV3_UPG, //int classnum;
+ PCL_A_O_LEV3_UPG, //int classnum;
"OffensiveLevel3-Upgrade", //char *classname;
"Offensive Level 3 Upgrade", //char *humanname;
"orbb", //char *modelname;
@@ -2222,12 +2222,12 @@ classAttributes_t bg_classList[ ] =
60, //int steptime;
1.3f, //float speed;
5.0f, //float sticky;
- { PCL_D_O_LEV4, PCL_NONE, PCL_NONE }, //int children[ 3 ];
+ { PCL_A_O_LEV4, PCL_NONE, PCL_NONE }, //int children[ 3 ];
3000, //int timetoevolve;
100 //int value;
},
{
- PCL_D_O_LEV4, //int classnum;
+ PCL_A_O_LEV4, //int classnum;
"OffensiveLevel4", //char *classname;
"Offensive Level 4", //char *humanname;
"xaero", //char *modelname;
@@ -2784,7 +2784,7 @@ weaponAttributes_t bg_weapons[ ] =
100, //int price;
SLOT_WEAPON, //int slots;
"dbuild", //char *weaponName;
- "Droid build weapon", //char *weaponHumanName;
+ "Alien build weapon", //char *weaponHumanName;
0, //int quan;
0, //int clips;
0, //int maxClips;
@@ -2797,7 +2797,7 @@ weaponAttributes_t bg_weapons[ ] =
100, //int price;
SLOT_WEAPON, //int slots;
"dbuild2", //char *weaponName;
- "Droid build weapon2",//char *weaponHumanName;
+ "Alien build weapon2",//char *weaponHumanName;
0, //int quan;
0, //int clips;
0, //int maxClips;
@@ -3416,7 +3416,7 @@ qboolean BG_CanItemBeGrabbed( int gametype, const entityState_t *ent, const pla
(item->giTag == PW_REDFLAG && ent->modelindex2) ||
(item->giTag == PW_REDFLAG && ps->powerups[PW_BLUEFLAG]))
return qtrue;*/
- } else if (ps->persistant[PERS_TEAM] == TEAM_DROIDS) {
+ } else if (ps->persistant[PERS_TEAM] == TEAM_ALIENS) {
/*if (item->giTag == PW_REDFLAG ||
(item->giTag == PW_BLUEFLAG && ent->modelindex2) ||
(item->giTag == PW_BLUEFLAG && ps->powerups[PW_REDFLAG]))
@@ -3634,7 +3634,7 @@ char *eventnames[] = {
"EV_POWERUP_REGEN",
"EV_GIB_PLAYER", // gib a previously living player
- "EV_GIB_DROID", //TA: generic green gib for droids
+ "EV_GIB_ALIEN", //TA: generic green gib for aliens
"EV_BUILD_CONSTRUCT", //TA
"EV_BUILD_DESTROY", //TA
diff --git a/src/game/bg_public.h b/src/game/bg_public.h
index 86d47a84..ed8af0fe 100644
--- a/src/game/bg_public.h
+++ b/src/game/bg_public.h
@@ -218,7 +218,7 @@ typedef enum {
STAT_WEAPONS2, //TA: another 16 bits to push the max weapon count up
STAT_ARMOR,
STAT_MAX_HEALTH, // health / armor limit, changable by handicap
- STAT_PCLASS, //TA: player class (for droids AND humans)
+ STAT_PCLASS, //TA: player class (for aliens AND humans)
STAT_PTEAM, //TA: player team
STAT_STAMINA, //TA: stamina (human only)
STAT_STATE, //TA: client states e.g. wall climbing
@@ -397,13 +397,13 @@ typedef enum
{
BA_NONE,
- BA_D_SPAWN,
- BA_D_HIVEMIND,
+ BA_A_SPAWN,
+ BA_A_HIVEMIND,
- BA_D_BARRICADE,
- BA_D_ACIDTUBE,
- BA_D_TRAPPER,
- BA_D_BOOSTER,
+ BA_A_BARRICADE,
+ BA_A_ACIDTUBE,
+ BA_A_TRAPPER,
+ BA_A_BOOSTER,
BA_H_SPAWN,
@@ -428,7 +428,7 @@ typedef enum
{
BIT_NONE,
- BIT_DROIDS,
+ BIT_ALIENS,
BIT_HUMANS,
BIT_NUM_TEAMS
@@ -542,7 +542,7 @@ typedef enum {
EV_POWERUP_REGEN,
EV_GIB_PLAYER, // gib a previously living player
- EV_GIB_DROID, //TA: generic green gib for droids
+ EV_GIB_ALIEN, //TA: generic green gib for aliens
EV_BUILD_CONSTRUCT, //TA
EV_BUILD_DESTROY, //TA
@@ -693,7 +693,7 @@ typedef struct animation_s {
typedef enum {
TEAM_FREE,
TEAM_HUMANS,
- TEAM_DROIDS,
+ TEAM_ALIENS,
TEAM_SPECTATOR,
TEAM_NUM_TEAMS
@@ -711,18 +711,18 @@ typedef enum {
PCL_NONE,
//builder classes
- PCL_D_B_BASE,
- PCL_D_B_LEV1,
+ PCL_A_B_BASE,
+ PCL_A_B_LEV1,
//offensive classes
- PCL_D_O_BASE,
- PCL_D_O_LEV1,
- PCL_D_O_LEV1_UPG,
- PCL_D_O_LEV2,
- PCL_D_O_LEV2_UPG,
- PCL_D_O_LEV3,
- PCL_D_O_LEV3_UPG,
- PCL_D_O_LEV4,
+ PCL_A_O_BASE,
+ PCL_A_O_LEV1,
+ PCL_A_O_LEV1_UPG,
+ PCL_A_O_LEV2,
+ PCL_A_O_LEV2_UPG,
+ PCL_A_O_LEV3,
+ PCL_A_O_LEV3_UPG,
+ PCL_A_O_LEV4,
//human class
PCL_H_BASE,
@@ -734,7 +734,7 @@ typedef enum {
//TA: player teams
typedef enum {
PTE_NONE,
- PTE_DROIDS,
+ PTE_ALIENS,
PTE_HUMANS,
PTE_NUM_TEAMS
diff --git a/src/game/g_active.c b/src/game/g_active.c
index e2961acc..d1f33eb2 100644
--- a/src/game/g_active.c
+++ b/src/game/g_active.c
@@ -350,7 +350,7 @@ void SpectatorThink( gentity_t *ent, usercmd_t *ucmd ) {
{
if( client->pers.pteam == PTE_NONE )
G_AddPredictableEvent( ent, EV_MENU, MN_TEAM );
- else if( client->pers.pteam == PTE_DROIDS )
+ else if( client->pers.pteam == PTE_ALIENS )
G_AddPredictableEvent( ent, EV_MENU, MN_D_CLASS );
else if( client->pers.pteam == PTE_HUMANS )
G_AddPredictableEvent( ent, EV_MENU, MN_H_SPAWN );
@@ -522,8 +522,8 @@ void ClientTimerActions( gentity_t *ent, int msec )
{
client->time1000 -= 1000;
- //replenish droid health
- if( client->ps.stats[ STAT_PTEAM ] == PTE_DROIDS )
+ //replenish alien health
+ if( client->ps.stats[ STAT_PTEAM ] == PTE_ALIENS )
{
if( ent->health < client->ps.stats[ STAT_MAX_HEALTH ] )
ent->health++;
@@ -859,7 +859,7 @@ void ClientThink_real( gentity_t *ent ) {
//TA: slow player if standing in creep
for ( i = 1, creepNode = g_entities + i; i < level.num_entities; i++, creepNode++ )
{
- if( creepNode->biteam == PTE_DROIDS )
+ if( creepNode->biteam == PTE_ALIENS )
{
VectorSubtract( client->ps.origin, creepNode->s.origin, temp_v );
diff --git a/src/game/g_buildable.c b/src/game/g_buildable.c
index db94e03c..2d771a97 100644
--- a/src/game/g_buildable.c
+++ b/src/game/g_buildable.c
@@ -189,7 +189,7 @@ qboolean findCreep( gentity_t *self )
if( !ent->classname || ent->s.eType != ET_BUILDABLE )
continue;
- if( ent->s.modelindex == BA_D_SPAWN || ent->s.modelindex == BA_D_HIVEMIND )
+ if( ent->s.modelindex == BA_A_SPAWN || ent->s.modelindex == BA_A_HIVEMIND )
{
/*VectorSubtract( self->s.origin, ent->s.origin, temp_v );*/
VectorSubtract( self->s.origin, ent->s.origin, temp_v );
@@ -243,12 +243,12 @@ static void freeBuildable( gentity_t *self )
/*
================
-D_CreepRecede
+A_CreepRecede
-Called when an droid spawn dies
+Called when an alien spawn dies
================
*/
-void D_CreepRecede( gentity_t *self )
+void A_CreepRecede( gentity_t *self )
{
//if the creep just died begin the recession
if( !( self->s.eFlags & EF_DEAD ) )
@@ -277,16 +277,16 @@ void D_CreepRecede( gentity_t *self )
/*
================
-DSpawn_Melt
+ASpawn_Melt
-Called when an droid spawn dies
+Called when an alien spawn dies
================
*/
-void DSpawn_Melt( gentity_t *self )
+void ASpawn_Melt( gentity_t *self )
{
//FIXME: this line crashes the QVM (but not binary when MOD is set to MOD_[H/D]SPAWN
G_SelectiveRadiusDamage( self->s.pos.trBase, self->parent, self->splashDamage,
- self->splashRadius, self, MOD_SHOTGUN, PTE_DROIDS );
+ self->splashRadius, self, MOD_SHOTGUN, PTE_ALIENS );
//start creep recession
if( !( self->s.eFlags & EF_DEAD ) )
@@ -307,12 +307,12 @@ void DSpawn_Melt( gentity_t *self )
/*
================
-DSpawn_Blast
+ASpawn_Blast
-Called when an droid spawn dies
+Called when an alien spawn dies
================
*/
-void DSpawn_Blast( gentity_t *self )
+void ASpawn_Blast( gentity_t *self )
{
vec3_t dir;
@@ -322,14 +322,14 @@ void DSpawn_Blast( gentity_t *self )
//do a bit of radius damage
G_SelectiveRadiusDamage( self->s.pos.trBase, self->parent, self->splashDamage,
- self->splashRadius, self, self->splashMethodOfDeath, PTE_DROIDS );
+ self->splashRadius, self, self->splashMethodOfDeath, PTE_ALIENS );
//pretty events and item cleanup
self->s.modelindex = 0; //don't draw the model once its destroyed
- G_AddEvent( self, EV_GIB_DROID, DirToByte( dir ) );
+ G_AddEvent( self, EV_GIB_ALIEN, DirToByte( dir ) );
self->r.contents = CONTENTS_TRIGGER;
self->timestamp = level.time;
- self->think = DSpawn_Melt;
+ self->think = ASpawn_Melt;
self->nextthink = level.time + 500; //wait .5 seconds before damaging others
trap_LinkEntity( self );
@@ -337,18 +337,18 @@ void DSpawn_Blast( gentity_t *self )
/*
================
-DSpawn_Die
+ASpawn_Die
-Called when an droid spawn dies
+Called when an alien spawn dies
================
*/
-void DSpawn_Die( gentity_t *self, gentity_t *inflictor, gentity_t *attacker, int damage, int mod )
+void ASpawn_Die( gentity_t *self, gentity_t *inflictor, gentity_t *attacker, int damage, int mod )
{
G_setBuildableAnim( self, BANIM_DESTROY1, qtrue );
G_setIdleBuildableAnim( self, BANIM_DESTROYED );
self->die = nullDieFunction;
- self->think = DSpawn_Blast;
+ self->think = ASpawn_Blast;
self->nextthink = level.time + 5000; //wait .5 seconds before damaging others
trap_LinkEntity( self );
@@ -356,12 +356,12 @@ void DSpawn_Die( gentity_t *self, gentity_t *inflictor, gentity_t *attacker, int
/*
================
-DSpawn_Think
+ASpawn_Think
-think function for Droid Spawn
+think function for Alien Spawn
================
*/
-void DSpawn_Think( gentity_t *self )
+void ASpawn_Think( gentity_t *self )
{
vec3_t mins, maxs, origin;
gentity_t *ent;
@@ -396,12 +396,12 @@ void DSpawn_Think( gentity_t *self )
/*
================
-DSpawn_Pain
+ASpawn_Pain
-pain function for Droid Spawn
+pain function for Alien Spawn
================
*/
-void DSpawn_Pain( gentity_t *self, gentity_t *attacker, int damage )
+void ASpawn_Pain( gentity_t *self, gentity_t *attacker, int damage )
{
G_setBuildableAnim( self, BANIM_PAIN1, qfalse );
}
@@ -414,12 +414,12 @@ void DSpawn_Pain( gentity_t *self, gentity_t *attacker, int damage )
/*
================
-DBarricade_Pain
+ABarricade_Pain
-pain function for Droid Spawn
+pain function for Alien Spawn
================
*/
-void DBarricade_Pain( gentity_t *self, gentity_t *attacker, int damage )
+void ABarricade_Pain( gentity_t *self, gentity_t *attacker, int damage )
{
if( random() > 0.5f )
G_setBuildableAnim( self, BANIM_PAIN1, qfalse );
@@ -429,12 +429,12 @@ void DBarricade_Pain( gentity_t *self, gentity_t *attacker, int damage )
/*
================
-DBarricade_Blast
+ABarricade_Blast
-Called when an droid spawn dies
+Called when an alien spawn dies
================
*/
-void DBarricade_Blast( gentity_t *self )
+void ABarricade_Blast( gentity_t *self )
{
vec3_t dir;
@@ -444,14 +444,14 @@ void DBarricade_Blast( gentity_t *self )
//do a bit of radius damage
G_SelectiveRadiusDamage( self->s.pos.trBase, self->parent, self->splashDamage,
- self->splashRadius, self, self->splashMethodOfDeath, PTE_DROIDS );
+ self->splashRadius, self, self->splashMethodOfDeath, PTE_ALIENS );
//pretty events and item cleanup
self->s.modelindex = 0; //don't draw the model once its destroyed
- G_AddEvent( self, EV_GIB_DROID, DirToByte( dir ) );
+ G_AddEvent( self, EV_GIB_ALIEN, DirToByte( dir ) );
self->r.contents = CONTENTS_TRIGGER;
self->timestamp = level.time;
- self->think = D_CreepRecede;
+ self->think = A_CreepRecede;
self->nextthink = level.time + 500; //wait .5 seconds before damaging others
trap_LinkEntity( self );
@@ -459,18 +459,18 @@ void DBarricade_Blast( gentity_t *self )
/*
================
-DBarricade_Die
+ABarricade_Die
-Called when an droid spawn dies
+Called when an alien spawn dies
================
*/
-void DBarricade_Die( gentity_t *self, gentity_t *inflictor, gentity_t *attacker, int damage, int mod )
+void ABarricade_Die( gentity_t *self, gentity_t *inflictor, gentity_t *attacker, int damage, int mod )
{
G_setBuildableAnim( self, BANIM_DESTROY1, qtrue );
G_setIdleBuildableAnim( self, BANIM_DESTROYED );
self->die = nullDieFunction;
- self->think = DBarricade_Blast;
+ self->think = ABarricade_Blast;
self->nextthink = level.time + 5000;
trap_LinkEntity( self );
@@ -478,12 +478,12 @@ void DBarricade_Die( gentity_t *self, gentity_t *inflictor, gentity_t *attacker,
/*
================
-DBarricade_Think
+ABarricade_Think
-think function for Droid Barricade
+think function for Alien Barricade
================
*/
-void DBarricade_Think( gentity_t *self )
+void ABarricade_Think( gentity_t *self )
{
//if there is no creep nearby die
if( !findCreep( self ) )
@@ -503,46 +503,46 @@ void DBarricade_Think( gentity_t *self )
-void DAcidTube_Think( gentity_t *self );
+void AAcidTube_Think( gentity_t *self );
/*
================
-DAcidTube_Damage
+AAcidTube_Damage
-damage function for Droid Acid Tube
+damage function for Alien Acid Tube
================
*/
-void DAcidTube_Damage( gentity_t *self )
+void AAcidTube_Damage( gentity_t *self )
{
if( !( self->s.eFlags & EF_FIRING ) )
{
self->s.eFlags |= EF_FIRING;
- G_AddEvent( self, EV_GIB_DROID, DirToByte( self->s.origin2 ) );
+ G_AddEvent( self, EV_GIB_ALIEN, DirToByte( self->s.origin2 ) );
}
if( ( self->timestamp + 10000 ) > level.time )
- self->think = DAcidTube_Damage;
+ self->think = AAcidTube_Damage;
else
{
- self->think = DAcidTube_Think;
+ self->think = AAcidTube_Think;
self->s.eFlags &= ~EF_FIRING;
}
//do some damage
G_SelectiveRadiusDamage( self->s.pos.trBase, self->parent, self->splashDamage,
- self->splashRadius, self, self->splashMethodOfDeath, PTE_DROIDS );
+ self->splashRadius, self, self->splashMethodOfDeath, PTE_ALIENS );
self->nextthink = level.time + BG_FindNextThinkForBuildable( self->s.modelindex );
}
/*
================
-DAcidTube_Think
+AAcidTube_Think
-think function for Droid Acid Tube
+think function for Alien Acid Tube
================
*/
-void DAcidTube_Think( gentity_t *self )
+void AAcidTube_Think( gentity_t *self )
{
int entityList[ MAX_GENTITIES ];
vec3_t range = { 200, 200, 200 };
@@ -569,7 +569,7 @@ void DAcidTube_Think( gentity_t *self )
if( enemy->client && enemy->client->ps.stats[ STAT_PTEAM ] == PTE_HUMANS )
{
self->timestamp = level.time;
- self->think = DAcidTube_Damage;
+ self->think = AAcidTube_Damage;
self->nextthink = level.time + 100;
G_setBuildableAnim( self, BANIM_ATTACK1, qfalse );
}
@@ -587,12 +587,12 @@ void DAcidTube_Think( gentity_t *self )
/*
================
-DBooster_Touch
+ABooster_Touch
Called when an alien touches a booster
================
*/
-void DBooster_Touch( gentity_t *self, gentity_t *other, trace_t *trace )
+void ABooster_Touch( gentity_t *self, gentity_t *other, trace_t *trace )
{
G_Printf( "%d is touching me\n", other->s.number );
}
@@ -608,12 +608,12 @@ void DBooster_Touch( gentity_t *self, gentity_t *other, trace_t *trace )
/*
================
-ddef_fireonemeny
+adef_fireonemeny
-Used by DDef2_Think to fire at enemy
+Used by ADef2_Think to fire at enemy
================
*/
-void ddef_fireonenemy( gentity_t *self, int firespeed )
+void adef_fireonenemy( gentity_t *self, int firespeed )
{
vec3_t dirToTarget;
vec3_t target;
@@ -650,12 +650,12 @@ void ddef_fireonenemy( gentity_t *self, int firespeed )
/*
================
-ddef_checktarget
+adef_checktarget
Used by DDef2_Think to check enemies for validity
================
*/
-qboolean ddef_checktarget( gentity_t *self, gentity_t *target, int range )
+qboolean adef_checktarget( gentity_t *self, gentity_t *target, int range )
{
vec3_t distance;
trace_t trace;
@@ -668,7 +668,7 @@ qboolean ddef_checktarget( gentity_t *self, gentity_t *target, int range )
return qfalse;
if( !target->client ) // is the target a bot or player?
return qfalse;
- if( target->client->ps.stats[ STAT_PTEAM ] == PTE_DROIDS ) // one of us?
+ if( target->client->ps.stats[ STAT_PTEAM ] == PTE_ALIENS ) // one of us?
return qfalse;
if( target->client->sess.sessionTeam == TEAM_SPECTATOR ) // is the target alive?
return qfalse;
@@ -695,12 +695,12 @@ qboolean ddef_checktarget( gentity_t *self, gentity_t *target, int range )
/*
================
-ddef_findenemy
+adef_findenemy
Used by DDef2_Think to locate enemy gentities
================
*/
-void ddef_findenemy( gentity_t *ent, int range )
+void adef_findenemy( gentity_t *ent, int range )
{
gentity_t *target;
@@ -722,12 +722,12 @@ void ddef_findenemy( gentity_t *ent, int range )
/*
================
-DTrapper_Think
+ATrapper_Think
-think function for Droid Defense
+think function for Alien Defense
================
*/
-void DTrapper_Think( gentity_t *self )
+void ATrapper_Think( gentity_t *self )
{
int range = BG_FindRangeForBuildable( self->s.modelindex );
int firespeed = BG_FindFireSpeedForBuildable( self->s.modelindex );
@@ -916,7 +916,7 @@ void HDCC_Think( gentity_t *self )
================
HMedistat_Think
-think function for Droid Acid Tube
+think function for Alien Acid Tube
================
*/
void HMedistat_Think( gentity_t *self )
@@ -1573,9 +1573,9 @@ itemBuildError_t G_itemFits( gentity_t *ent, buildable_t buildable, int distance
if( tr2.fraction < 1.0 || tr3.fraction < 1.0 )
return IBE_NOROOM; //NO other reason is allowed to override this
- if( ent->client->ps.stats[ STAT_PTEAM ] == PTE_DROIDS )
+ if( ent->client->ps.stats[ STAT_PTEAM ] == PTE_ALIENS )
{
- //droid criteria
+ //alien criteria
float minNormal = BG_FindMinNormalForBuildable( buildable );
qboolean invert = BG_FindInvertNormalForBuildable( buildable );
@@ -1589,14 +1589,14 @@ itemBuildError_t G_itemFits( gentity_t *ent, buildable_t buildable, int distance
{
if( !tempent->classname || tempent->s.eType != ET_BUILDABLE )
continue;
- if( tempent->s.modelindex == BA_D_HIVEMIND )
+ if( tempent->s.modelindex == BA_A_HIVEMIND )
break;
}
//if none found...
- if( i >= level.num_entities && buildable != BA_D_HIVEMIND )
+ if( i >= level.num_entities && buildable != BA_A_HIVEMIND )
{
- if( buildable == BA_D_SPAWN )
+ if( buildable == BA_A_SPAWN )
reason = IBE_SPWNWARN;
else
reason = IBE_NOHIVEMIND;
@@ -1610,7 +1610,7 @@ itemBuildError_t G_itemFits( gentity_t *ent, buildable_t buildable, int distance
if( !tempent->classname || tempent->s.eType != ET_BUILDABLE )
continue;
- if( tempent->s.modelindex == BA_D_HIVEMIND )
+ if( tempent->s.modelindex == BA_A_HIVEMIND )
{
reason = IBE_HIVEMIND;
break;
@@ -1618,7 +1618,7 @@ itemBuildError_t G_itemFits( gentity_t *ent, buildable_t buildable, int distance
}
}
- if( level.droidBuildPoints - BG_FindBuildPointsForBuildable( buildable ) < 0 )
+ if( level.alienBuildPoints - BG_FindBuildPointsForBuildable( buildable ) < 0 )
reason = IBE_NOASSERT;
}
else if( ent->client->ps.stats[ STAT_PTEAM ] == PTE_HUMANS )
@@ -1744,40 +1744,40 @@ gentity_t *G_buildItem( gentity_t *builder, buildable_t buildable, vec3_t origin
//things that vary for each buildable that aren't in the dbase
switch( buildable )
{
- case BA_D_SPAWN:
- built->die = DSpawn_Die;
- built->think = DSpawn_Think;
- built->pain = DSpawn_Pain;
+ case BA_A_SPAWN:
+ built->die = ASpawn_Die;
+ built->think = ASpawn_Think;
+ built->pain = ASpawn_Pain;
break;
- case BA_D_BARRICADE:
- built->die = DBarricade_Die;
- built->think = DBarricade_Think;
- built->pain = DBarricade_Pain;
+ case BA_A_BARRICADE:
+ built->die = ABarricade_Die;
+ built->think = ABarricade_Think;
+ built->pain = ABarricade_Pain;
break;
- case BA_D_BOOSTER:
- built->die = DBarricade_Die;
- built->think = DBarricade_Think;
- built->pain = DBarricade_Pain;
- built->touch = DBooster_Touch;
+ case BA_A_BOOSTER:
+ built->die = ABarricade_Die;
+ built->think = ABarricade_Think;
+ built->pain = ABarricade_Pain;
+ built->touch = ABooster_Touch;
break;
- case BA_D_ACIDTUBE:
- built->die = DBarricade_Die;
- built->think = DAcidTube_Think;
- built->pain = DSpawn_Pain;
+ case BA_A_ACIDTUBE:
+ built->die = ABarricade_Die;
+ built->think = AAcidTube_Think;
+ built->pain = ASpawn_Pain;
break;
- case BA_D_TRAPPER:
- built->die = DBarricade_Die;
- built->think = DTrapper_Think;
- built->pain = DSpawn_Pain;
+ case BA_A_TRAPPER:
+ built->die = ABarricade_Die;
+ built->think = ATrapper_Think;
+ built->pain = ASpawn_Pain;
break;
- case BA_D_HIVEMIND:
- built->die = DSpawn_Die;
- built->pain = DSpawn_Pain;
+ case BA_A_HIVEMIND:
+ built->die = ASpawn_Die;
+ built->pain = ASpawn_Pain;
break;
case BA_H_SPAWN:
diff --git a/src/game/g_combat.c b/src/game/g_combat.c
index 232d1ee1..5ac3126b 100644
--- a/src/game/g_combat.c
+++ b/src/game/g_combat.c
@@ -191,7 +191,7 @@ void GibEntity( gentity_t *self, int killer )
if( self->client->ps.stats[ STAT_PTEAM ] == PTE_HUMANS )
G_AddEvent( self, EV_GIB_PLAYER, killer );
else
- G_AddEvent( self, EV_GIB_DROID, killer );
+ G_AddEvent( self, EV_GIB_ALIEN, killer );
self->takedamage = qfalse;
self->s.eType = ET_INVISIBLE;
@@ -266,7 +266,7 @@ void CheckAlmostCapture( gentity_t *self, gentity_t *attacker ) {
self->client->ps.powerups[PW_NEUTRALFLAG] ) {
// get the goal flag this player should have been going for
if ( g_gametype.integer == GT_CTF ) {
- if ( self->client->sess.sessionTeam == TEAM_DROIDS ) {
+ if ( self->client->sess.sessionTeam == TEAM_ALIENS ) {
classname = "team_CTF_blueflag";
}
else {
@@ -274,7 +274,7 @@ void CheckAlmostCapture( gentity_t *self, gentity_t *attacker ) {
}
}
else {
- if ( self->client->sess.sessionTeam == TEAM_DROIDS ) {
+ if ( self->client->sess.sessionTeam == TEAM_ALIENS ) {
classname = "team_CTF_redflag";
}
else {
@@ -312,7 +312,7 @@ void CheckAlmostScored( gentity_t *self, gentity_t *attacker ) {
// if the player was carrying cubes
if ( self->client->ps.generic1 ) {
- if ( self->client->sess.sessionTeam == TEAM_DROIDS ) {
+ if ( self->client->sess.sessionTeam == TEAM_ALIENS ) {
classname = "team_redobelisk";
}
else {
@@ -1253,7 +1253,7 @@ void G_Damage( gentity_t *targ, gentity_t *inflictor, gentity_t *attacker,
//TA: add to the attackers "account" on the target
if( targ->client && attacker->client &&
- targ->client->ps.stats[ STAT_PTEAM ] == PTE_DROIDS &&
+ targ->client->ps.stats[ STAT_PTEAM ] == PTE_ALIENS &&
attacker->client->ps.stats[ STAT_PTEAM ] == PTE_HUMANS )
targ->credits[ attacker->client->ps.clientNum ] += take;
diff --git a/src/game/g_local.h b/src/game/g_local.h
index 1a4f6982..c176fc53 100644
--- a/src/game/g_local.h
+++ b/src/game/g_local.h
@@ -457,16 +457,16 @@ typedef struct {
gentity_t *locationHead; // head of the location list
//TA: extra stuff:
- int numDroidSpawns;
+ int numAlienSpawns;
int numHumanSpawns;
- int numDroidClients;
+ int numAlienClients;
int numHumanClients;
- int numLiveDroidClients;
+ int numLiveAlienClients;
int numLiveHumanClients;
- int droidBuildPoints;
+ int alienBuildPoints;
int humanBuildPoints;
int humanBuildPointsPowered;
@@ -847,7 +847,7 @@ extern vmCvar_t g_enableBreath;
extern vmCvar_t g_singlePlayer;
extern vmCvar_t g_humanBuildPoints;
-extern vmCvar_t g_droidBuildPoints;
+extern vmCvar_t g_alienBuildPoints;
void trap_Printf( const char *fmt );
void trap_Error( const char *fmt );
diff --git a/src/game/g_main.c b/src/game/g_main.c
index 377eabf9..a36b15ac 100644
--- a/src/game/g_main.c
+++ b/src/game/g_main.c
@@ -77,7 +77,7 @@ vmCvar_t g_listEntity;
//TA
vmCvar_t g_humanBuildPoints;
-vmCvar_t g_droidBuildPoints;
+vmCvar_t g_alienBuildPoints;
static cvarTable_t gameCvarTable[] = {
// don't override the cheat state set by the system
@@ -148,7 +148,7 @@ static cvarTable_t gameCvarTable[] = {
{ &pmove_msec, "pmove_msec", "8", CVAR_SYSTEMINFO, 0, qfalse},
{ &g_humanBuildPoints, "g_humanBuildPoints", "1000", 0, 0, qfalse },
- { &g_droidBuildPoints, "g_droidBuildPoints", "1000", 0, 0, qfalse },
+ { &g_alienBuildPoints, "g_alienBuildPoints", "1000", 0, 0, qfalse },
{ &g_rankings, "g_rankings", "0", 0, 0, qfalse}
};
@@ -758,7 +758,7 @@ void countSpawns( void )
int i;
gentity_t *ent;
- level.numDroidSpawns = 0;
+ level.numAlienSpawns = 0;
level.numHumanSpawns = 0;
for ( i = 1, ent = g_entities + i ; i < level.num_entities ; i++, ent++ )
@@ -766,8 +766,8 @@ void countSpawns( void )
if (!ent->inuse)
continue;
- if( !Q_stricmp( ent->classname, "team_droid_spawn" ) && ent->health > 0 )
- level.numDroidSpawns++;
+ if( !Q_stricmp( ent->classname, "team_alien_spawn" ) && ent->health > 0 )
+ level.numAlienSpawns++;
if( !Q_stricmp( ent->classname, "team_human_spawn" ) && ent->health > 0 )
level.numHumanSpawns++;
@@ -788,10 +788,10 @@ void calculateBuildPoints( void )
int bclass;
gentity_t *ent;
int localHTP = g_humanBuildPoints.integer,
- localDTP = g_droidBuildPoints.integer;
+ localDTP = g_alienBuildPoints.integer;
level.humanBuildPoints = level.humanBuildPointsPowered = localHTP;
- level.droidBuildPoints = localDTP;
+ level.alienBuildPoints = localDTP;
for ( i = 1, ent = g_entities + i ; i < level.num_entities ; i++, ent++ )
{
@@ -811,7 +811,7 @@ void calculateBuildPoints( void )
}
else
{
- level.droidBuildPoints -= BG_FindBuildPointsForBuildable( bclass );
+ level.alienBuildPoints -= BG_FindBuildPointsForBuildable( bclass );
}
}
}
@@ -825,12 +825,12 @@ void calculateBuildPoints( void )
if( level.humanBuildPoints < 0 )
{
- localDTP -= level.droidBuildPoints;
- level.droidBuildPoints = 0;
+ localDTP -= level.alienBuildPoints;
+ level.alienBuildPoints = 0;
}
trap_SetConfigstring( CS_BUILDPOINTS,
- va( "%d %d %d %d %d", level.droidBuildPoints,
+ va( "%d %d %d %d %d", level.alienBuildPoints,
localDTP,
level.humanBuildPoints,
localHTP,
@@ -860,9 +860,9 @@ void CalculateRanks( void ) {
level.numNonSpectatorClients = 0;
level.numPlayingClients = 0;
level.numVotingClients = 0; // don't count bots
- level.numDroidClients = 0;
+ level.numAlienClients = 0;
level.numHumanClients = 0;
- level.numLiveDroidClients = 0;
+ level.numLiveAlienClients = 0;
level.numLiveHumanClients = 0;
for ( i = 0; i < TEAM_NUM_TEAMS; i++ ) {
@@ -877,11 +877,11 @@ void CalculateRanks( void ) {
level.numConnectedClients++;
//TA: so we know when the game ends and for team leveling
- if( level.clients[i].pers.pteam == PTE_DROIDS )
+ if( level.clients[i].pers.pteam == PTE_ALIENS )
{
- level.numDroidClients++;
+ level.numAlienClients++;
if ( level.clients[i].sess.sessionTeam != TEAM_SPECTATOR )
- level.numLiveDroidClients++;
+ level.numLiveAlienClients++;
}
if( level.clients[i].pers.pteam == PTE_HUMANS )
@@ -904,7 +904,7 @@ void CalculateRanks( void ) {
level.numVotingClients++;
if ( level.clients[i].sess.sessionTeam == TEAM_HUMANS )
level.numteamVotingClients[0]++;
- else if ( level.clients[i].sess.sessionTeam == TEAM_DROIDS )
+ else if ( level.clients[i].sess.sessionTeam == TEAM_ALIENS )
level.numteamVotingClients[1]++;
if ( level.follow1 == -1 )
@@ -925,9 +925,9 @@ void CalculateRanks( void ) {
// in team games, rank is just the order of the teams, 0=red, 1=blue, 2=tied
for ( i = 0; i < level.numConnectedClients; i++ ) {
cl = &level.clients[ level.sortedClients[i] ];
- if ( level.teamScores[TEAM_HUMANS] == level.teamScores[TEAM_DROIDS] ) {
+ if ( level.teamScores[TEAM_HUMANS] == level.teamScores[TEAM_ALIENS] ) {
cl->ps.persistant[PERS_RANK] = 2;
- } else if ( level.teamScores[TEAM_HUMANS] > level.teamScores[TEAM_DROIDS] ) {
+ } else if ( level.teamScores[TEAM_HUMANS] > level.teamScores[TEAM_ALIENS] ) {
cl->ps.persistant[PERS_RANK] = 0;
} else {
cl->ps.persistant[PERS_RANK] = 1;
@@ -958,7 +958,7 @@ void CalculateRanks( void ) {
// set the CS_SCORES1/2 configstrings, which will be visible to everyone
if ( g_gametype.integer >= GT_TEAM ) {
trap_SetConfigstring( CS_SCORES1, va("%i", level.teamScores[TEAM_HUMANS] ) );
- trap_SetConfigstring( CS_SCORES2, va("%i", level.teamScores[TEAM_DROIDS] ) );
+ trap_SetConfigstring( CS_SCORES2, va("%i", level.teamScores[TEAM_ALIENS] ) );
} else {
if ( level.numConnectedClients == 0 ) {
trap_SetConfigstring( CS_SCORES1, va("%i", SCORE_NOT_PRESENT) );
@@ -1152,7 +1152,7 @@ void ExitLevel (void) {
// reset all the scores so we don't enter the intermission again
level.teamScores[TEAM_HUMANS] = 0;
- level.teamScores[TEAM_DROIDS] = 0;
+ level.teamScores[TEAM_ALIENS] = 0;
for ( i=0 ; i< g_maxclients.integer ; i++ ) {
cl = level.clients + i;
if ( cl->pers.connected != CON_CONNECTED ) {
@@ -1240,7 +1240,7 @@ void LogExit( const char *string ) {
if ( g_gametype.integer >= GT_TEAM ) {
G_LogPrintf( "red:%i blue:%i\n",
- level.teamScores[TEAM_HUMANS], level.teamScores[TEAM_DROIDS] );
+ level.teamScores[TEAM_HUMANS], level.teamScores[TEAM_ALIENS] );
}
for (i=0 ; i < numSorted ; i++) {
@@ -1364,7 +1364,7 @@ qboolean ScoreIsTied( void ) {
}
if ( g_gametype.integer >= GT_TEAM ) {
- return level.teamScores[TEAM_HUMANS] == level.teamScores[TEAM_DROIDS];
+ return level.teamScores[TEAM_HUMANS] == level.teamScores[TEAM_ALIENS];
}
a = level.clients[level.sortedClients[0]].ps.persistant[PERS_SCORE];
@@ -1416,17 +1416,17 @@ void CheckExitRules( void ) {
}
/*trap_SendServerCommand( -1, va("print \"%d %d %d %d %d %d\n\"",
- level.numDroidClients,
- level.numLiveDroidClients,
+ level.numAlienClients,
+ level.numLiveAlienClients,
level.numHumanClients,
level.numLiveHumanClients,
- level.numDroidSpawns,
+ level.numAlienSpawns,
level.numHumanSpawns ) );*/
//TA: end the game on these conditions
- if( ( level.time > level.startTime + 1000 ) && ( level.numDroidSpawns == 0 ) && ( level.numLiveDroidClients == 0 ) )
+ if( ( level.time > level.startTime + 1000 ) && ( level.numAlienSpawns == 0 ) && ( level.numLiveAlienClients == 0 ) )
{
- //droids lose
+ //aliens lose
trap_SendServerCommand( -1, "print \"Humans win.\n\"");
LogExit( "Humans win." );
return;
@@ -1434,8 +1434,8 @@ void CheckExitRules( void ) {
else if( ( level.time > level.startTime + 1000 ) && ( level.numHumanSpawns == 0 ) && ( level.numLiveHumanClients == 0 ) )
{
//humans lose
- trap_SendServerCommand( -1, "print \"Droids win.\n\"");
- LogExit( "Droids win." );
+ trap_SendServerCommand( -1, "print \"Aliens win.\n\"");
+ LogExit( "Aliens win." );
return;
}
@@ -1450,7 +1450,7 @@ void CheckExitRules( void ) {
return;
}
- if ( level.teamScores[TEAM_DROIDS] >= g_fraglimit.integer ) {
+ if ( level.teamScores[TEAM_ALIENS] >= g_fraglimit.integer ) {
trap_SendServerCommand( -1, "print \"Blue hit the fraglimit.\n\"" );
LogExit( "Fraglimit hit." );
return;
@@ -1482,7 +1482,7 @@ void CheckExitRules( void ) {
return;
}
- if ( level.teamScores[TEAM_DROIDS] >= g_capturelimit.integer ) {
+ if ( level.teamScores[TEAM_ALIENS] >= g_capturelimit.integer ) {
trap_SendServerCommand( -1, "print \"Blue hit the capturelimit.\n\"" );
LogExit( "Capturelimit hit." );
return;
@@ -1563,10 +1563,10 @@ void CheckTournament( void ) {
qboolean notEnough = qfalse;
if ( g_gametype.integer > GT_TEAM ) {
- counts[TEAM_DROIDS] = TeamCount( -1, TEAM_DROIDS );
+ counts[TEAM_ALIENS] = TeamCount( -1, TEAM_ALIENS );
counts[TEAM_HUMANS] = TeamCount( -1, TEAM_HUMANS );
- if (counts[TEAM_HUMANS] < 1 || counts[TEAM_DROIDS] < 1) {
+ if (counts[TEAM_HUMANS] < 1 || counts[TEAM_ALIENS] < 1) {
notEnough = qtrue;
}
} else if ( level.numPlayingClients < 2 ) {
@@ -1732,7 +1732,7 @@ void CheckTeamVote( int team ) {
if ( team == TEAM_HUMANS )
cs_offset = 0;
- else if ( team == TEAM_DROIDS )
+ else if ( team == TEAM_ALIENS )
cs_offset = 1;
else
return;
@@ -1964,7 +1964,7 @@ end = trap_Milliseconds();
// check team votes
CheckTeamVote( TEAM_HUMANS );
- CheckTeamVote( TEAM_DROIDS );
+ CheckTeamVote( TEAM_ALIENS );
// for tracking changes
CheckCvars();
diff --git a/src/game/g_spawn.c b/src/game/g_spawn.c
index adb90db9..f2ffbcd3 100644
--- a/src/game/g_spawn.c
+++ b/src/game/g_spawn.c
@@ -141,7 +141,7 @@ void SP_info_player_deathmatch (gentity_t *ent);
void SP_info_player_intermission (gentity_t *ent);
//TA: extra bits
-void SP_info_droid_intermission( gentity_t *ent );
+void SP_info_alien_intermission( gentity_t *ent );
void SP_info_human_intermission( gentity_t *ent );
void SP_info_firstplace(gentity_t *ent);
@@ -214,7 +214,7 @@ spawn_t spawns[] = {
{"info_player_intermission", SP_info_player_intermission},
//TA: extra bits
- {"info_droid_intermission", SP_info_droid_intermission},
+ {"info_alien_intermission", SP_info_alien_intermission},
{"info_human_intermission", SP_info_human_intermission},
{"info_null", SP_info_null},
@@ -616,8 +616,8 @@ void SP_worldspawn( void ) {
G_SpawnString( "humanBuildPoints", "1000", &s );
trap_Cvar_Set( "g_humanBuildPoints", s );
- G_SpawnString( "droidBuildPoints", "1000", &s );
- trap_Cvar_Set( "g_droidBuildPoints", s );
+ G_SpawnString( "alienBuildPoints", "1000", &s );
+ trap_Cvar_Set( "g_alienBuildPoints", s );
G_SpawnString( "enableDust", "0", &s );
trap_Cvar_Set( "g_enableDust", s );
diff --git a/src/game/g_target.c b/src/game/g_target.c
index f3daba36..e2bc25ff 100644
--- a/src/game/g_target.c
+++ b/src/game/g_target.c
@@ -66,7 +66,7 @@ void Use_target_remove_powerups( gentity_t *ent, gentity_t *other, gentity_t *ac
/*if( activator->client->ps.powerups[PW_REDFLAG] ) {
Team_ReturnFlag( TEAM_HUMANS );
} else if( activator->client->ps.powerups[PW_BLUEFLAG] ) {
- Team_ReturnFlag( TEAM_DROIDS );
+ Team_ReturnFlag( TEAM_ALIENS );
} else if( activator->client->ps.powerups[PW_NEUTRALFLAG] ) {
Team_ReturnFlag( TEAM_FREE );
}*/
@@ -144,7 +144,7 @@ void Use_Target_Print (gentity_t *ent, gentity_t *other, gentity_t *activator) {
G_TeamCommand( TEAM_HUMANS, va("cp \"%s\"", ent->message) );
}
if ( ent->spawnflags & 2 ) {
- G_TeamCommand( TEAM_DROIDS, va("cp \"%s\"", ent->message) );
+ G_TeamCommand( TEAM_ALIENS, va("cp \"%s\"", ent->message) );
}
return;
}
@@ -374,7 +374,7 @@ void target_relay_use (gentity_t *self, gentity_t *other, gentity_t *activator)
return;
}
if ( ( self->spawnflags & 2 ) && activator->client
- && activator->client->sess.sessionTeam != TEAM_DROIDS ) {
+ && activator->client->sess.sessionTeam != TEAM_ALIENS ) {
return;
}
if ( self->spawnflags & 4 ) {
diff --git a/src/game/g_team.c b/src/game/g_team.c
index 56819ef7..74817043 100644
--- a/src/game/g_team.c
+++ b/src/game/g_team.c
@@ -39,7 +39,7 @@ void Team_InitGame(void)
case GT_CTF:
teamgame.redStatus = teamgame.blueStatus = -1; // Invalid to force update
Team_SetFlagStatus( TEAM_HUMANS, FLAG_ATBASE );
- Team_SetFlagStatus( TEAM_DROIDS, FLAG_ATBASE );
+ Team_SetFlagStatus( TEAM_ALIENS, FLAG_ATBASE );
break;
default:
break;
@@ -48,8 +48,8 @@ void Team_InitGame(void)
int OtherTeam(int team) {
if (team==TEAM_HUMANS)
- return TEAM_DROIDS;
- else if (team==TEAM_DROIDS)
+ return TEAM_ALIENS;
+ else if (team==TEAM_ALIENS)
return TEAM_HUMANS;
return team;
}
@@ -57,7 +57,7 @@ int OtherTeam(int team) {
const char *TeamName(int team) {
if (team==TEAM_HUMANS)
return "RED";
- else if (team==TEAM_DROIDS)
+ else if (team==TEAM_ALIENS)
return "BLUE";
else if (team==TEAM_SPECTATOR)
return "SPECTATOR";
@@ -67,7 +67,7 @@ const char *TeamName(int team) {
const char *OtherTeamName(int team) {
if (team==TEAM_HUMANS)
return "BLUE";
- else if (team==TEAM_DROIDS)
+ else if (team==TEAM_ALIENS)
return "RED";
else if (team==TEAM_SPECTATOR)
return "SPECTATOR";
@@ -77,7 +77,7 @@ const char *OtherTeamName(int team) {
const char *TeamColorString(int team) {
if (team==TEAM_HUMANS)
return S_COLOR_RED;
- else if (team==TEAM_DROIDS)
+ else if (team==TEAM_ALIENS)
return S_COLOR_BLUE;
else if (team==TEAM_SPECTATOR)
return S_COLOR_YELLOW;
@@ -119,12 +119,12 @@ void AddTeamScore(vec3_t origin, int team, int score) {
te->r.svFlags |= SVF_BROADCAST;
if ( team == TEAM_HUMANS ) {
- if ( level.teamScores[ TEAM_HUMANS ] + score == level.teamScores[ TEAM_DROIDS ] ) {
+ if ( level.teamScores[ TEAM_HUMANS ] + score == level.teamScores[ TEAM_ALIENS ] ) {
//teams are tied sound
//te->s.eventParm = GTS_TEAMS_ARE_TIED;
}
- else if ( level.teamScores[ TEAM_HUMANS ] <= level.teamScores[ TEAM_DROIDS ] &&
- level.teamScores[ TEAM_HUMANS ] + score > level.teamScores[ TEAM_DROIDS ]) {
+ else if ( level.teamScores[ TEAM_HUMANS ] <= level.teamScores[ TEAM_ALIENS ] &&
+ level.teamScores[ TEAM_HUMANS ] + score > level.teamScores[ TEAM_ALIENS ]) {
// red took the lead sound
//te->s.eventParm = GTS_REDTEAM_TOOK_LEAD;
}
@@ -134,12 +134,12 @@ void AddTeamScore(vec3_t origin, int team, int score) {
}
}
else {
- if ( level.teamScores[ TEAM_DROIDS ] + score == level.teamScores[ TEAM_HUMANS ] ) {
+ if ( level.teamScores[ TEAM_ALIENS ] + score == level.teamScores[ TEAM_HUMANS ] ) {
//teams are tied sound
//te->s.eventParm = GTS_TEAMS_ARE_TIED;
}
- else if ( level.teamScores[ TEAM_DROIDS ] <= level.teamScores[ TEAM_HUMANS ] &&
- level.teamScores[ TEAM_DROIDS ] + score > level.teamScores[ TEAM_HUMANS ]) {
+ else if ( level.teamScores[ TEAM_ALIENS ] <= level.teamScores[ TEAM_HUMANS ] &&
+ level.teamScores[ TEAM_ALIENS ] + score > level.teamScores[ TEAM_HUMANS ]) {
// blue took the lead sound
//te->s.eventParm = GTS_BLUETEAM_TOOK_LEAD;
}
@@ -187,7 +187,7 @@ void Team_SetFlagStatus( int team, flagStatus_t status ) {
}
break;
- case TEAM_DROIDS: // CTF
+ case TEAM_ALIENS: // CTF
if( teamgame.blueStatus != status ) {
teamgame.blueStatus = status;
modified = qtrue;
@@ -225,7 +225,7 @@ void Team_CheckDroppedItem( gentity_t *dropped )
/*if (dropped->item->giTag == PW_REDFLAG)
Team_SetFlagStatus( TEAM_HUMANS, FLAG_DROPPED );
else if (dropped->item->giTag == PW_BLUEFLAG)
- Team_SetFlagStatus( TEAM_DROIDS, FLAG_DROPPED );*/
+ Team_SetFlagStatus( TEAM_ALIENS, FLAG_DROPPED );*/
}
@@ -375,7 +375,7 @@ void Team_FragBonuses(gentity_t *targ, gentity_t *inflictor, gentity_t *attacker
case TEAM_HUMANS:
c = "team_CTF_redflag";
break;
- case TEAM_DROIDS:
+ case TEAM_ALIENS:
c = "team_CTF_blueflag";
break;
default:
@@ -483,7 +483,7 @@ gentity_t *Team_ResetFlag(int team)
case TEAM_HUMANS:
c = "team_CTF_redflag";
break;
- case TEAM_DROIDS:
+ case TEAM_ALIENS:
c = "team_CTF_blueflag";
break;
case TEAM_FREE:
@@ -511,7 +511,7 @@ gentity_t *Team_ResetFlag(int team)
void Team_ResetFlags( void ) {
if( g_gametype.integer == GT_CTF ) {
Team_ResetFlag( TEAM_HUMANS );
- Team_ResetFlag( TEAM_DROIDS );
+ Team_ResetFlag( TEAM_ALIENS );
}
}
@@ -526,7 +526,7 @@ void Team_ReturnFlagSound(gentity_t *ent, int team)
}
//te = G_TempEntity( ent->s.pos.trBase, EV_GLOBAL_TEAM_SOUND );
- if( team == TEAM_DROIDS ) {
+ if( team == TEAM_ALIENS ) {
//te->s.eventParm = GTS_RED_RETURN;
}
else {
@@ -554,7 +554,7 @@ void Team_TakeFlagSound( gentity_t *ent, int team ) {
teamgame.blueTakenTime = level.time;
break;
- case TEAM_DROIDS: // CTF
+ case TEAM_ALIENS: // CTF
if( teamgame.redStatus != FLAG_ATBASE ) {
if (teamgame.redTakenTime > level.time - 10000)
return;
@@ -564,7 +564,7 @@ void Team_TakeFlagSound( gentity_t *ent, int team ) {
}
//te = G_TempEntity( ent->s.pos.trBase, EV_GLOBAL_TEAM_SOUND );
- if( team == TEAM_DROIDS ) {
+ if( team == TEAM_ALIENS ) {
//te->s.eventParm = GTS_RED_TAKEN;
}
else {
@@ -582,7 +582,7 @@ void Team_CaptureFlagSound( gentity_t *ent, int team ) {
}
//te = G_TempEntity( ent->s.pos.trBase, EV_GLOBAL_TEAM_SOUND );
- if( team == TEAM_DROIDS ) {
+ if( team == TEAM_ALIENS ) {
//te->s.eventParm = GTS_BLUE_CAPTURE;
}
else {
@@ -606,7 +606,7 @@ void Team_FreeEntity(gentity_t *ent)
/*if (ent->item->giTag == PW_REDFLAG)
Team_ReturnFlag(TEAM_HUMANS);
else if (ent->item->giTag == PW_BLUEFLAG)
- Team_ReturnFlag(TEAM_DROIDS);*/
+ Team_ReturnFlag(TEAM_ALIENS);*/
}
/*
@@ -623,7 +623,7 @@ void Team_DroppedFlagThink(gentity_t *ent)
/*if (ent->item->giTag == PW_REDFLAG)
Team_ReturnFlagSound(Team_ResetFlag(TEAM_HUMANS), TEAM_HUMANS);
else if (ent->item->giTag == PW_BLUEFLAG)
- Team_ReturnFlagSound(Team_ResetFlag(TEAM_DROIDS), TEAM_DROIDS);*/
+ Team_ReturnFlagSound(Team_ResetFlag(TEAM_ALIENS), TEAM_ALIENS);*/
// Reset Flag will delete this entity
}
@@ -734,7 +734,7 @@ int Pickup_Team( gentity_t *ent, gentity_t *other ) {
if (strcmp(ent->classname, "team_CTF_redflag") == 0)
team = TEAM_HUMANS;
else if (strcmp(ent->classname, "team_CTF_blueflag") == 0)
- team = TEAM_DROIDS;
+ team = TEAM_ALIENS;
else {
PrintMsg ( other, "Don't know what team the flag is on.\n");
return 0;
@@ -833,14 +833,14 @@ gentity_t *SelectRandomTeamSpawnPoint( int teamstate, team_t team ) {
if (teamstate == TEAM_BEGIN) {
if (team == TEAM_HUMANS)
classname = "team_CTF_redplayer";
- else if (team == TEAM_DROIDS)
+ else if (team == TEAM_ALIENS)
classname = "team_CTF_blueplayer";
else
return NULL;
} else {
if (team == TEAM_HUMANS)
classname = "team_CTF_redspawn";
- else if (team == TEAM_DROIDS)
+ else if (team == TEAM_ALIENS)
classname = "team_CTF_bluespawn";
else
return NULL;
@@ -978,7 +978,7 @@ void CheckTeamStatus(void)
continue;
}
- if (ent->inuse && (ent->client->sess.sessionTeam == TEAM_HUMANS || ent->client->sess.sessionTeam == TEAM_DROIDS)) {
+ if (ent->inuse && (ent->client->sess.sessionTeam == TEAM_HUMANS || ent->client->sess.sessionTeam == TEAM_ALIENS)) {
loc = Team_GetLocation( ent );
if (loc)
@@ -994,7 +994,7 @@ void CheckTeamStatus(void)
continue;
}
- if (ent->inuse && (ent->client->sess.sessionTeam == TEAM_HUMANS || ent->client->sess.sessionTeam == TEAM_DROIDS)) {
+ if (ent->inuse && (ent->client->sess.sessionTeam == TEAM_HUMANS || ent->client->sess.sessionTeam == TEAM_ALIENS)) {
TeamplayInfoMessage( ent );
}
}
diff --git a/src/game/g_trigger.c b/src/game/g_trigger.c
index 99f0d8a9..b3636d61 100644
--- a/src/game/g_trigger.c
+++ b/src/game/g_trigger.c
@@ -48,7 +48,7 @@ void multi_trigger( gentity_t *ent, gentity_t *activator ) {
return;
}
if ( ( ent->spawnflags & 2 ) &&
- activator->client->sess.sessionTeam != TEAM_DROIDS ) {
+ activator->client->sess.sessionTeam != TEAM_ALIENS ) {
return;
}
}
diff --git a/src/game/g_weapon.c b/src/game/g_weapon.c
index d6467e02..a9c3b66f 100644
--- a/src/game/g_weapon.c
+++ b/src/game/g_weapon.c
@@ -683,7 +683,7 @@ qboolean CheckVenomAttack( gentity_t *ent )
return qfalse;
if( !traceEnt->client )
return qfalse;
- if( traceEnt->client->ps.stats[ STAT_PTEAM ] == PTE_DROIDS )
+ if( traceEnt->client->ps.stats[ STAT_PTEAM ] == PTE_ALIENS )
return qfalse;
// send blood impact
@@ -793,7 +793,7 @@ void Weapon_Grab_Fire( gentity_t *ent )
return;
if( !traceEnt->client )
return;
- if( traceEnt->client->ps.stats[ STAT_PTEAM ] == PTE_DROIDS )
+ if( traceEnt->client->ps.stats[ STAT_PTEAM ] == PTE_ALIENS )
return;
if( traceEnt->client )
@@ -835,7 +835,7 @@ qboolean CheckGrabAttack( gentity_t *ent )
return qfalse;
if( !traceEnt->client )
return qfalse;
- if( traceEnt->client->ps.stats[ STAT_PTEAM ] == PTE_DROIDS )
+ if( traceEnt->client->ps.stats[ STAT_PTEAM ] == PTE_ALIENS )
return qfalse;
return qtrue;
diff --git a/src/ui/ui_main.c b/src/ui/ui_main.c
index 03840d00..50fbeec6 100644
--- a/src/ui/ui_main.c
+++ b/src/ui/ui_main.c
@@ -2839,19 +2839,19 @@ static void UI_LoadTremAlienClasses( )
uiInfo.tremAlienClassCount = 3;
uiInfo.tremAlienClassList[ 0 ].text =
- String_Alloc( BG_FindHumanNameForClassNum( PCL_D_B_BASE ) );
+ String_Alloc( BG_FindHumanNameForClassNum( PCL_A_B_BASE ) );
uiInfo.tremAlienClassList[ 0 ].cmd =
- String_Alloc( va( "cmd class %s", BG_FindNameForClassNum( PCL_D_B_BASE ) ) );
+ String_Alloc( va( "cmd class %s", BG_FindNameForClassNum( PCL_A_B_BASE ) ) );
uiInfo.tremAlienClassList[ 1 ].text =
- String_Alloc( BG_FindHumanNameForClassNum( PCL_D_B_LEV1 ) );
+ String_Alloc( BG_FindHumanNameForClassNum( PCL_A_B_LEV1 ) );
uiInfo.tremAlienClassList[ 1 ].cmd =
- String_Alloc( va( "cmd class %s", BG_FindNameForClassNum( PCL_D_B_LEV1 ) ) );
+ String_Alloc( va( "cmd class %s", BG_FindNameForClassNum( PCL_A_B_LEV1 ) ) );
uiInfo.tremAlienClassList[ 2 ].text =
- String_Alloc( BG_FindHumanNameForClassNum( PCL_D_O_BASE ) );
+ String_Alloc( BG_FindHumanNameForClassNum( PCL_A_O_BASE ) );
uiInfo.tremAlienClassList[ 2 ].cmd =
- String_Alloc( va( "cmd class %s", BG_FindNameForClassNum( PCL_D_O_BASE ) ) );
+ String_Alloc( va( "cmd class %s", BG_FindNameForClassNum( PCL_A_O_BASE ) ) );
}
/*
@@ -3009,7 +3009,7 @@ static void UI_LoadTremAlienBuilds( )
for( i = BA_NONE +1; i < BA_NUM_BUILDABLES; i++ )
{
- if( BG_FindTeamForBuildable( i ) == BIT_DROIDS )
+ if( BG_FindTeamForBuildable( i ) == BIT_ALIENS )
{
uiInfo.tremAlienBuildList[ j ].text =
String_Alloc( BG_FindHumanNameForBuildable( i ) );
diff --git a/src/cgame/cg_event.c b/src/cgame/cg_event.c
index 24a9e988..b8f87a84 100644
--- a/src/cgame/cg_event.c
+++ b/src/cgame/cg_event.c
@@ -830,7 +830,7 @@ void CG_EntityEvent( centity_t *cent, vec3_t position )
trap_S_StartSound (NULL, es->number, CHAN_AUTO, cgs.media.respawnSound );
break;
//TA: make droid items "grow"
case EV_BUILD_CONSTRUCT:
DEBUGNAME("EV_BUILD_CONSTRUCT");
cent->miscTime = cg.time; // scale up from this
@@ -839,7 +839,7 @@ void CG_EntityEvent( centity_t *cent, vec3_t position )
cent->buildableAnim = es->eventParm;
break;
//TA: make droid creep "recede"
case EV_BUILD_DESTROY:
DEBUGNAME("EV_BUILD_DESTROY");
cent->miscTime = -cg.time; // scale down from this
@@ -1033,8 +1033,8 @@ void CG_EntityEvent( centity_t *cent, vec3_t position )
CG_GibPlayer( cent->lerpOrigin );
break;
- case EV_GIB_DROID:
- DEBUGNAME("EV_GIB_DROID");
+ case EV_GIB_ALIEN:
+ DEBUGNAME("EV_GIB_ALIEN");
trap_S_StartSound( NULL, es->number, CHAN_BODY, cgs.media.gibSound );
CG_GenericGib( cent->lerpOrigin );
break;
@@ -830,7 +830,7 @@ void CG_EntityEvent( centity_t *cent, vec3_t position )
trap_S_StartSound (NULL, es->number, CHAN_AUTO, cgs.media.respawnSound );
break;
- //TA: make droid items "grow"
+ //TA: make alien items "grow"
case EV_BUILD_CONSTRUCT:
DEBUGNAME("EV_BUILD_CONSTRUCT");
@@ -839,7 +839,7 @@ void CG_EntityEvent( centity_t *cent, vec3_t position )
cent->buildableAnim = es->eventParm;
break;
- //TA: make droid creep "recede"
+ //TA: make alien creep "recede"
case EV_BUILD_DESTROY:
DEBUGNAME("EV_BUILD_DESTROY");
diff --git a/src/game/g_client.c b/src/game/g_client.c
index bbb6c5fb..99de9e8b 100644
--- a/src/game/g_client.c
+++ b/src/game/g_client.c
@@ -56,10 +56,10 @@ void SP_info_player_intermission( gentity_t *ent ) {
}
-/*QUAKED info_droid_intermission (1 0 1) (-16 -16 -24) (16 16 32)
+/*QUAKED info_alien_intermission (1 0 1) (-16 -16 -24) (16 16 32)
The intermission will be viewed from this point. Target an info_notnull for the view direction.
*/
-void SP_info_droid_intermission( gentity_t *ent ) {
+void SP_info_alien_intermission( gentity_t *ent ) {
}
@@ -243,12 +243,12 @@ gentity_t *SelectRandomFurthestSpawnPoint ( vec3_t avoidPoint, vec3_t origin, ve
/*
================
-SelectDroidSpawnPoint
+SelectAlienSpawnPoint
go to a random point that doesn't telefrag
================
*/
-gentity_t *SelectDroidSpawnPoint( void )
+gentity_t *SelectAlienSpawnPoint( void )
{
gentity_t *spot;
int count;
@@ -265,7 +265,7 @@ gentity_t *SelectDroidSpawnPoint( void )
count = 0;
spot = NULL;
- while( ( spot = G_Find( spot, FOFS( classname ), "team_droid_spawn" ) ) != NULL )
+ while( ( spot = G_Find( spot, FOFS( classname ), "team_alien_spawn" ) ) != NULL )
{
if( SpotWouldTelefrag( spot ) || ( spot->health <= 0 ) )
continue;
@@ -291,7 +291,7 @@ gentity_t *SelectDroidSpawnPoint( void )
if( !count )
{
// no spots that won't telefrag
- spot = G_Find( NULL, FOFS( classname ), "team_droid_spawn" );
+ spot = G_Find( NULL, FOFS( classname ), "team_alien_spawn" );
if( spot->health > 0 )
return spot;
@@ -417,8 +417,8 @@ gentity_t *SelectTremulousSpawnPoint( int team, vec3_t origin, vec3_t angles )
vec3_t classMins, classMaxs, spawnMins, spawnMaxs;
vec3_t normal = { 0, 0, 1 };
- if( team == PTE_DROIDS )
- spot = SelectDroidSpawnPoint( );
+ if( team == PTE_ALIENS )
+ spot = SelectAlienSpawnPoint( );
else if( team == PTE_HUMANS )
spot = SelectHumanSpawnPoint( );
@@ -429,9 +429,9 @@ gentity_t *SelectTremulousSpawnPoint( int team, vec3_t origin, vec3_t angles )
VectorCopy( spot->s.pos.trBase, origin );
VectorCopy( spot->s.angles, angles );
- if( team == PTE_DROIDS )
+ if( team == PTE_ALIENS )
{
- BG_FindBBoxForBuildable( BA_D_SPAWN, spawnMins, spawnMaxs );
+ BG_FindBBoxForBuildable( BA_A_SPAWN, spawnMins, spawnMaxs );
//TA: really a *safe* extreme upper limit
displacement = ( spawnMaxs[ 2 ] + MAX_ALIEN_BBOX + 1.0f ) * M_ROOT3;
@@ -498,17 +498,17 @@ gentity_t *SelectSpectatorSpawnPoint( vec3_t origin, vec3_t angles ) {
/*
===========
-SelectDroidLockSpawnPoint
+SelectAlienLockSpawnPoint
-Try to find a spawn point for droid intermission otherwise
+Try to find a spawn point for alien intermission otherwise
use normal intermission spawn.
============
*/
-gentity_t *SelectDroidLockSpawnPoint( vec3_t origin, vec3_t angles ) {
+gentity_t *SelectAlienLockSpawnPoint( vec3_t origin, vec3_t angles ) {
gentity_t *spot;
spot = NULL;
- spot = G_Find (spot, FOFS(classname), "info_droid_intermission");
+ spot = G_Find (spot, FOFS(classname), "info_alien_intermission");
if ( !spot ) {
return SelectSpectatorSpawnPoint( origin, angles );
@@ -590,10 +590,10 @@ void useBody( gentity_t *self, gentity_t *other, gentity_t *activator )
vec3_t up = { 0.0, 0.0, 1.0 };
- if( activator->client->ps.stats[ STAT_PTEAM ] == PTE_DROIDS )
+ if( activator->client->ps.stats[ STAT_PTEAM ] == PTE_ALIENS )
{
//can't pick teammates bodies to bits
- if( !Q_stricmp( self->classname, "droidCorpse" ) )
+ if( !Q_stricmp( self->classname, "alienCorpse" ) )
return;
//can't use bodies that are not owned
@@ -639,7 +639,7 @@ void useBody( gentity_t *self, gentity_t *other, gentity_t *activator )
if( ( self->credits[ clientNum ] == 0 || !self->creditsHash[ clientNum ] ) && total != 0 )
continue;
- G_AddEvent( self, EV_GIB_DROID, DirToByte( up ) );
+ G_AddEvent( self, EV_GIB_ALIEN, DirToByte( up ) );
self->freeAfterEvent = qtrue;
break;
}
@@ -695,7 +695,7 @@ void SpawnCorpse( gentity_t *ent )
}
else
{
- body->classname = "droidCorpse";
+ body->classname = "alienCorpse";
for( i = 0; i < MAX_CLIENTS; body->credits[ i ] = ent->credits[ i++ ] );
}
@@ -861,20 +861,20 @@ PickTeam
team_t PickTeam( int ignoreClientNum ) {
int counts[TEAM_NUM_TEAMS];
- counts[TEAM_DROIDS] = TeamCount( ignoreClientNum, TEAM_DROIDS );
+ counts[TEAM_ALIENS] = TeamCount( ignoreClientNum, TEAM_ALIENS );
counts[TEAM_HUMANS] = TeamCount( ignoreClientNum, TEAM_HUMANS );
- if ( counts[TEAM_DROIDS] > counts[TEAM_HUMANS] ) {
+ if ( counts[TEAM_ALIENS] > counts[TEAM_HUMANS] ) {
return TEAM_HUMANS;
}
- if ( counts[TEAM_HUMANS] > counts[TEAM_DROIDS] ) {
- return TEAM_DROIDS;
+ if ( counts[TEAM_HUMANS] > counts[TEAM_ALIENS] ) {
+ return TEAM_ALIENS;
}
// equal team count, so join the team with the lowest score
- if ( level.teamScores[TEAM_DROIDS] > level.teamScores[TEAM_HUMANS] ) {
+ if ( level.teamScores[TEAM_ALIENS] > level.teamScores[TEAM_HUMANS] ) {
return TEAM_HUMANS;
}
- return TEAM_DROIDS;
+ return TEAM_ALIENS;
}
/*
@@ -1067,7 +1067,7 @@ void ClientUserinfoChanged( int clientNum ) {
case TEAM_HUMANS:
//ForceClientSkin(client, model, "red");
break;
- case TEAM_DROIDS:
+ case TEAM_ALIENS:
//ForceClientSkin(client, model, "blue");
break;
}
@@ -1095,7 +1095,7 @@ void ClientUserinfoChanged( int clientNum ) {
strcpy(c1, Info_ValueForKey( userinfo, "color1" ));
strcpy(c2, Info_ValueForKey( userinfo, "color2" ));
strcpy(redTeam, "humans");
- strcpy(blueTeam, "droids");
+ strcpy(blueTeam, "aliens");
// send over a subset of the userinfo keys so other clients can
// print scoreboards, display models, and play custom sounds
@@ -1321,8 +1321,8 @@ void ClientSpawn( gentity_t *ent, gentity_t *spawn )
{
if( teamLocal == PTE_NONE )
spawnPoint = SelectSpectatorSpawnPoint ( spawn_origin, spawn_angles);
- else if( teamLocal == PTE_DROIDS )
- spawnPoint = SelectDroidLockSpawnPoint ( spawn_origin, spawn_angles);
+ else if( teamLocal == PTE_ALIENS )
+ spawnPoint = SelectAlienLockSpawnPoint ( spawn_origin, spawn_angles);
else if( teamLocal == PTE_HUMANS )
spawnPoint = SelectHumanLockSpawnPoint ( spawn_origin, spawn_angles);
}
@@ -1331,7 +1331,7 @@ void ClientSpawn( gentity_t *ent, gentity_t *spawn )
//this is an infest spawn
if( spawn )
{
//spawn as new droid
VectorCopy( spawn->s.pos.trBase, spawn_origin );
VectorCopy( spawn->s.angles, spawn_angles );
@@ -1339,7 +1339,7 @@ void ClientSpawn( gentity_t *ent, gentity_t *spawn )
BG_FindBBoxForClass( ent->client->pers.pclass, classMins, NULL, NULL, NULL, NULL );
spawn_origin[ 2 ] += bodyMaxs[ 2 ] + fabs( classMins[ 2 ] ) + 1;
- G_AddEvent( spawn, EV_GIB_DROID, DirToByte( up ) );
+ G_AddEvent( spawn, EV_GIB_ALIEN, DirToByte( up ) );
spawn->freeAfterEvent = qtrue;
}
else
@@ -1389,7 +1389,7 @@ void ClientSpawn( gentity_t *ent, gentity_t *spawn )
if( client->sess.sessionTeam == TEAM_SPECTATOR )
{
- if( teamLocal == PTE_DROIDS )
+ if( teamLocal == PTE_ALIENS )
G_AddPredictableEvent( ent, EV_MENU, MN_D_CLASS );
else if( teamLocal == PTE_HUMANS )
G_AddPredictableEvent( ent, EV_MENU, MN_H_SPAWN );
@@ -1436,52 +1436,52 @@ void ClientSpawn( gentity_t *ent, gentity_t *spawn )
// clear entity values
switch( ent->client->pers.pclass )
{
- case PCL_D_B_BASE:
+ case PCL_A_B_BASE:
BG_packWeapon( WP_DBUILD, client->ps.stats );
BG_packAmmoArray( WP_DBUILD, client->ps.ammo, client->ps.powerups, 0, 0, 0 );
break;
- case PCL_D_B_LEV1:
+ case PCL_A_B_LEV1:
BG_packWeapon( WP_DBUILD2, client->ps.stats );
BG_packAmmoArray( WP_DBUILD2, client->ps.ammo, client->ps.powerups, 0, 0, 0 );
break;
- case PCL_D_O_BASE:
+ case PCL_A_O_BASE:
BG_packWeapon( WP_VENOM, client->ps.stats );
BG_packAmmoArray( WP_VENOM, client->ps.ammo, client->ps.powerups, 0, 0, 0 );
break;
- case PCL_D_O_LEV1:
+ case PCL_A_O_LEV1:
BG_packWeapon( WP_GRABANDCSAW, client->ps.stats );
BG_packAmmoArray( WP_GRABANDCSAW, client->ps.ammo, client->ps.powerups, 0, 0, 0 );
break;
- case PCL_D_O_LEV1_UPG:
+ case PCL_A_O_LEV1_UPG:
BG_packWeapon( WP_GRABANDCSAW, client->ps.stats );
BG_packAmmoArray( WP_GRABANDCSAW, client->ps.ammo, client->ps.powerups, 0, 0, 0 );
break;
- case PCL_D_O_LEV2:
+ case PCL_A_O_LEV2:
BG_packWeapon( WP_POUNCE, client->ps.stats );
BG_packAmmoArray( WP_POUNCE, client->ps.ammo, client->ps.powerups, 0, 0, 0 );
break;
- case PCL_D_O_LEV2_UPG:
+ case PCL_A_O_LEV2_UPG:
BG_packWeapon( WP_POUNCE, client->ps.stats );
BG_packAmmoArray( WP_POUNCE, client->ps.ammo, client->ps.powerups, 0, 0, 0 );
break;
- case PCL_D_O_LEV3:
+ case PCL_A_O_LEV3:
BG_packWeapon( WP_VENOM, client->ps.stats );
BG_packAmmoArray( WP_VENOM, client->ps.ammo, client->ps.powerups, 0, 0, 0 );
break;
- case PCL_D_O_LEV3_UPG:
+ case PCL_A_O_LEV3_UPG:
BG_packWeapon( WP_VENOM, client->ps.stats );
BG_packAmmoArray( WP_VENOM, client->ps.ammo, client->ps.powerups, 0, 0, 0 );
break;
- case PCL_D_O_LEV4:
+ case PCL_A_O_LEV4:
BG_packWeapon( WP_VENOM, client->ps.stats );
BG_packAmmoArray( WP_VENOM, client->ps.ammo, client->ps.powerups, 0, 0, 0 );
break;
@@ -1526,7 +1526,7 @@ void ClientSpawn( gentity_t *ent, gentity_t *spawn )
#define F_VEL 50.0f
//give aliens some spawn velocity
- if( client->ps.stats[ STAT_PTEAM ] == PTE_DROIDS )
+ if( client->ps.stats[ STAT_PTEAM ] == PTE_ALIENS )
{
if( spawnPoint->s.origin2[ 2 ] > 0.0f )
{
@@ -1563,7 +1563,7 @@ void ClientSpawn( gentity_t *ent, gentity_t *spawn )
client->ps.pm_flags |= PMF_TIME_KNOCKBACK;
client->ps.pm_time = 100;
//TA: STAT_SPAWNTIME for droid fov effects
client->respawnTime = level.time;
G_AddPredictableEvent( ent, EV_PLAYER_RESPAWN, 0 );
@@ -1331,7 +1331,7 @@ void ClientSpawn( gentity_t *ent, gentity_t *spawn )
if( spawn )
{
- //spawn as new droid
+ //spawn as new alien
VectorCopy( spawn->s.pos.trBase, spawn_origin );
VectorCopy( spawn->s.angles, spawn_angles );
@@ -1563,7 +1563,7 @@ void ClientSpawn( gentity_t *ent, gentity_t *spawn )
client->ps.pm_flags |= PMF_TIME_KNOCKBACK;
client->ps.pm_time = 100;
- //TA: STAT_SPAWNTIME for droid fov effects
+ //TA: STAT_SPAWNTIME for alien fov effects
client->respawnTime = level.time;
G_AddPredictableEvent( ent, EV_PLAYER_RESPAWN, 0 );
diff --git a/src/game/g_cmds.c b/src/game/g_cmds.c
index a9ac286f..72f3d457 100644
--- a/src/game/g_cmds.c
+++ b/src/game/g_cmds.c
@@ -62,7 +62,7 @@ void DeathmatchScoreboardMessage( gentity_t *ent ) {
}
trap_SendServerCommand( ent-g_entities, va("scores %i %i %i%s", i,
- level.teamScores[TEAM_HUMANS], level.teamScores[TEAM_DROIDS],
+ level.teamScores[TEAM_HUMANS], level.teamScores[TEAM_ALIENS],
string ) );
}
@@ -442,8 +442,8 @@ void BroadcastTeamChange( gclient_t *client, int oldTeam )
if ( client->sess.sessionTeam == TEAM_HUMANS ) {
trap_SendServerCommand( -1, va("cp \"%s" S_COLOR_WHITE " joined the humans.\n\"",
client->pers.netname) );
- } else if ( client->sess.sessionTeam == TEAM_DROIDS ) {
- trap_SendServerCommand( -1, va("cp \"%s" S_COLOR_WHITE " joined the droids.\n\"",
+ } else if ( client->sess.sessionTeam == TEAM_ALIENS ) {
+ trap_SendServerCommand( -1, va("cp \"%s" S_COLOR_WHITE " joined the aliens.\n\"",
client->pers.netname));
} else if ( client->sess.sessionTeam == TEAM_SPECTATOR && oldTeam != TEAM_SPECTATOR ) {
trap_SendServerCommand( -1, va("cp \"%s" S_COLOR_WHITE " joined the spectators.\n\"",
@@ -494,8 +494,8 @@ void SetTeam( gentity_t *ent, char *s ) {
specState = SPECTATOR_NOT;
if ( !Q_stricmp( s, "humans" ) || !Q_stricmp( s, "h" ) ) {
team = TEAM_HUMANS;
- } else if ( !Q_stricmp( s, "droids" ) || !Q_stricmp( s, "d" ) ) {
- team = TEAM_DROIDS;
+ } else if ( !Q_stricmp( s, "aliens" ) || !Q_stricmp( s, "d" ) ) {
+ team = TEAM_ALIENS;
} else {
// pick the team with the least number of players
team = PickTeam( clientNum );
@@ -504,18 +504,18 @@ void SetTeam( gentity_t *ent, char *s ) {
if ( g_teamForceBalance.integer ) {
int counts[TEAM_NUM_TEAMS];
- counts[TEAM_DROIDS] = TeamCount( ent->client->ps.clientNum, TEAM_DROIDS );
+ counts[TEAM_ALIENS] = TeamCount( ent->client->ps.clientNum, TEAM_ALIENS );
counts[TEAM_HUMANS] = TeamCount( ent->client->ps.clientNum, TEAM_HUMANS );
// We allow a spread of two
- if ( team == TEAM_HUMANS && counts[TEAM_HUMANS] - counts[TEAM_DROIDS] > 1 ) {
+ if ( team == TEAM_HUMANS && counts[TEAM_HUMANS] - counts[TEAM_ALIENS] > 1 ) {
trap_SendServerCommand( ent->client->ps.clientNum,
"cp \"Humans team has too many players.\n\"" );
return; // ignore the request
}
- if ( team == TEAM_DROIDS && counts[TEAM_DROIDS] - counts[TEAM_HUMANS] > 1 ) {
+ if ( team == TEAM_ALIENS && counts[TEAM_ALIENS] - counts[TEAM_HUMANS] > 1 ) {
trap_SendServerCommand( ent->client->ps.clientNum,
- "cp \"Droids team has too many players.\n\"" );
+ "cp \"Aliens team has too many players.\n\"" );
return; // ignore the request
}
@@ -615,7 +615,7 @@ void Cmd_Team_f( gentity_t *ent ) {
if( !Q_stricmp( s, "0" ) || !Q_stricmp( s, "spectate" ) )
ent->client->pers.pteam = PTE_NONE;
else if( !Q_stricmp( s, "1" ) || !Q_stricmp( s, "aliens" ) )
- ent->client->pers.pteam = PTE_DROIDS;
+ ent->client->pers.pteam = PTE_ALIENS;
else if( !Q_stricmp( s, "2" ) || !Q_stricmp( s, "humans" ) )
ent->client->pers.pteam = PTE_HUMANS;
@@ -1304,7 +1304,7 @@ void Cmd_CallTeamVote_f( gentity_t *ent ) {
team = ent->client->sess.sessionTeam;
if ( team == TEAM_HUMANS )
cs_offset = 0;
- else if ( team == TEAM_DROIDS )
+ else if ( team == TEAM_ALIENS )
cs_offset = 1;
else
return;
@@ -1432,7 +1432,7 @@ void Cmd_TeamVote_f( gentity_t *ent ) {
team = ent->client->sess.sessionTeam;
if ( team == TEAM_HUMANS )
cs_offset = 0;
- else if ( team == TEAM_DROIDS )
+ else if ( team == TEAM_ALIENS )
cs_offset = 1;
else
return;
@@ -1554,14 +1554,14 @@ void Cmd_Class_f( gentity_t *ent )
int i;
trace_t tr;
vec3_t infestOrigin, infestAngles;
- int allowedClasses[ NUM_AC ] = { PCL_D_B_BASE,
- PCL_D_B_LEV1,
- PCL_D_O_BASE };
+ int allowedClasses[ NUM_AC ] = { PCL_A_B_BASE,
+ PCL_A_B_LEV1,
+ PCL_A_O_BASE };
clientNum = ent->client - level.clients;
trap_Argv( 1, s, sizeof( s ) );
- if( ent->client->pers.pteam == PTE_DROIDS )
+ if( ent->client->pers.pteam == PTE_ALIENS )
{
//if we are not currently spectating, we are attempting evolution
if( ent->client->pers.pclass != PCL_NONE )
@@ -1810,7 +1810,7 @@ void Cmd_Buy_f( gentity_t *ent )
trap_Argv( 1, s, sizeof( s ) );
//droids don't buy stuff
if( ent->client->pers.pteam != PTE_HUMANS )
return;
@@ -1931,7 +1931,7 @@ void Cmd_Sell_f( gentity_t *ent )
trap_Argv( 1, s, sizeof( s ) );
//droids don't sell stuff
if( ent->client->pers.pteam != PTE_HUMANS )
return;
@@ -2003,7 +2003,7 @@ void Cmd_Deposit_f( gentity_t *ent )
trap_Argv( 1, s, sizeof( s ) );
//droids don't sell stuff
if( ent->client->pers.pteam != PTE_HUMANS )
return;
@@ -2058,7 +2058,7 @@ void Cmd_Withdraw_f( gentity_t *ent )
trap_Argv( 1, s, sizeof( s ) );
//droids don't sell stuff
if( ent->client->pers.pteam != PTE_HUMANS )
return;
@@ -1810,7 +1810,7 @@ void Cmd_Buy_f( gentity_t *ent )
trap_Argv( 1, s, sizeof( s ) );
- //droids don't buy stuff
+ //aliens don't buy stuff
if( ent->client->pers.pteam != PTE_HUMANS )
return;
@@ -1931,7 +1931,7 @@ void Cmd_Sell_f( gentity_t *ent )
trap_Argv( 1, s, sizeof( s ) );
- //droids don't sell stuff
+ //aliens don't sell stuff
if( ent->client->pers.pteam != PTE_HUMANS )
return;
@@ -2003,7 +2003,7 @@ void Cmd_Deposit_f( gentity_t *ent )
trap_Argv( 1, s, sizeof( s ) );
- //droids don't sell stuff
+ //aliens don't sell stuff
if( ent->client->pers.pteam != PTE_HUMANS )
return;
@@ -2058,7 +2058,7 @@ void Cmd_Withdraw_f( gentity_t *ent )
trap_Argv( 1, s, sizeof( s ) );
- //droids don't sell stuff
+ //aliens don't sell stuff
if( ent->client->pers.pteam != PTE_HUMANS )
return;